﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace Evolucion
{
    /// <summary>
    /// clase que tiene los procesos para cargar los datos de los ComboBox de windows Forms, además de la lista de chekedListBox.
    /// </summary>
   public static class CargaDatos
    {
        /// <summary>
        /// Metodo en el que cargamos las distintas métricas a escoger para gráficar en el programa
        /// </summary>
        /// <param name="cbTipoGrafico">ComoBox donde cargamos las métricas</param>
        public static void cargarCbGraficas(ComboBox cbTipoGrafico)
        {
            try
            {
                cbTipoGrafico.Items.Clear();
                cbTipoGrafico.Items.Add("Marcador");
                cbTipoGrafico.Items.Add("Porcentaje de error");
                cbTipoGrafico.Items.Add("Media y desviacón");
                cbTipoGrafico.Items.Add("Facilidad de movimiento");
                cbTipoGrafico.Items.Add("Tiempo de reacción");
                cbTipoGrafico.Items.Add("Número de temblores");
                cbTipoGrafico.Items.Add("Simetría direccional en x e y");
                cbTipoGrafico.Items.Add("Simetria velocidad y ángulo");
                cbTipoGrafico.Items.Add("Evolución de la fuerza");
                cbTipoGrafico.SelectedIndex = -1;
            }
            catch (Exception ex)
            {
                MessageBox.Show("Error debido a: " + ex.Message
                   + "\r\nError debido a: " + ex.Source
                   + "\r\nError debido a: " + ex.StackTrace
                   + "\r\nError debido a: " + ex.TargetSite);
                Application.Exit();
            }
        }
        /// <summary>
        /// Funcion que carga el comboBox de cbPacientes a traves de una consulta a la BBDD
        /// </summary>
        /// <param name="cbPaciente">ComboBox en el que cargamos la id de los pacientes</param>
        /// <param name="bd">Base de datos de donde sacamos las id de los pacientes</param>
        public static void cargarCbPacientes(ComboBox cbPaciente, bbddDataContext bd)
        {
            try
            {
                cbPaciente.DataSource = null;
                cbPaciente.Items.Clear();
                var resultado = (from consulta in bd.PacientesBM
                                 orderby consulta.IdPaciente
                                 select consulta).Distinct().ToList();
                cbPaciente.DataSource = resultado;
                cbPaciente.DisplayMember = "IdPaciente"; //Mostramos tanto nombre como apellidos.
                cbPaciente.ValueMember = "IdPaciente";
                cbPaciente.SelectedIndex = -1; // Preseleccionamos el indice para que no haya errores.

            }
            catch (Exception er)
            {
                MessageBox.Show("error debido a" + er.Message +
                          "\r\n error debido a" + er.Source +
                          "\r\n error debido a" + er.StackTrace +
                          "\r\n error debido a" + er.InnerException);
                Application.Exit();
            }
        }
        /// <summary>
        /// Función encargada de cargar el ComboBox del tipo de terapia que vamos a utilizar
        /// </summary>
        /// <param name="cbTipoTerapia">ComoBox en el que cargamos los nombres de los distintos tipos de terapias</param>
        public static void cargarCbTipoTerapia(ComboBox cbTipoTerapia)
        {
            try
            {
                cbTipoTerapia.Items.Clear();
                cbTipoTerapia.Items.Add("Activo asistido");
                cbTipoTerapia.Items.Add("Pasivo");
                cbTipoTerapia.Items.Add("AVD Biblioteca");
                cbTipoTerapia.Items.Add("AVD Telefono");
                cbTipoTerapia.Items.Add("AVD Imagenes");
                cbTipoTerapia.Items.Add("GRADIOR ACTIVO");
                cbTipoTerapia.Items.Add("GRADIOR PASIVO");
                cbTipoTerapia.Items.Add("Tunel Horizontal");
                cbTipoTerapia.Items.Add("Piramide");
                cbTipoTerapia.Items.Add("Doble_Piramide");
                cbTipoTerapia.SelectedIndex = -1; // Preseleccionamos el indice para que no haya errores.

            }
            catch (Exception ex)
            {
                MessageBox.Show("Error debido a: " + ex.Message
                    + "\r\nError debido a: " + ex.Source
                    + "\r\nError debido a: " + ex.StackTrace
                    + "\r\nError debido a: " + ex.TargetSite);
                Application.Exit();
            }
        }
        /// <summary>
        ///  Metodo que desactiva los controles de usuario cuando se inicia el programa salvo el ComboBox de cbPaciente
        /// </summary>
        /// <param name="cbTipoTerapia">ComboBox que selecciona el tipo de terapia</param>
        /// <param name="cbTipoGrafico">ComboBox que selecciona el tipo de gráfico</param>
        /// <param name="BotonCargarGrafica">Botón que carga el gráfico en el programa </param>
        /// <param name="cbRangoTerapiaInferior">ComboBox en el que seleccinamos la primera terápia a representar</param>
        /// <param name="CbRangoTerapiaSuperior">ComboBox en el que seleccinamos la ultima terápia a representar</param>
        /// <param name="ListaGraficos">CheckedListBox que contiene todas las métriacas que se quieren incluir en el informe</param>
        /// <param name="botonGenerarInforme">Boton encargado de generar el informe en PDF</param>
        public static void desactivarControles(ComboBox cbTipoTerapia, ComboBox cbTipoGrafico, Button BotonCargarGrafica, ComboBox cbRangoTerapiaInferior, ComboBox CbRangoTerapiaSuperior, CheckedListBox ListaGraficos, Button botonGenerarInforme)
        { 
            cbTipoTerapia.Enabled = false;
            cbTipoGrafico.Enabled = false;
            BotonCargarGrafica.Enabled = false;
            cbRangoTerapiaInferior.Enabled = false;
            CbRangoTerapiaSuperior.Enabled = false;
            ListaGraficos.Enabled = false;
            botonGenerarInforme.Enabled = false;
        }
        /// <summary>
        /// Funcion que carga el ComboBox tanto del "cbRangoTerapiaInferior" como el del "CbRangoTerapiaSuperior", Apoyandose en la creación de dos listas auxiliares y realizando una cosnsulta a la BBDD.
        /// </summary>
        /// <param name="CbRangoTerapiaSuperior">ComboBox en el que seleccinamos la ultima terápia a representar</param>
        /// <param name="cbRangoTerapiaInferior">ComboBox en el que seleccinamos la primera terápia a representar</param>
        /// <param name="bd">Es nuestra base de datos</param>
        /// <param name="cbPaciente">ComboBox en el que cargamos las id´s del paciente</param>
        public static void cargarCbRango(ComboBox CbRangoTerapiaSuperior, ComboBox cbRangoTerapiaInferior,bbddDataContext bd,ComboBox cbPaciente)
        {
            string idPacienteSeleccionado = cbPaciente.SelectedValue.ToString();
            CbRangoTerapiaSuperior.DataSource = null;
            CbRangoTerapiaSuperior.Items.Clear();
            cbRangoTerapiaInferior.DataSource = null;
            cbRangoTerapiaInferior.Items.Clear();
            List<int> ListaRangoSuperior = new List<int>();
            List<int> ListaRangoInferor = new List<int>();
            List<int> resultado = (from consulta in bd.TerapiaBM
                                   where consulta.IdPaciente == int.Parse(idPacienteSeleccionado)
                                   orderby consulta.IdTerapia
                                   select consulta.IdTerapia).Distinct().ToList();

            foreach (int item in resultado)
            {
                
                    ListaRangoSuperior.Add(item);
                    ListaRangoInferor.Add(item);
            }

            CbRangoTerapiaSuperior.DataSource = ListaRangoSuperior;
            cbRangoTerapiaInferior.DataSource = ListaRangoInferor;

        }
        /// <summary>
        /// Metodo en el que cargamos una lista con las distintas métricas que podemos elegir si incluir o no en el informe
        /// </summary>
        /// <param name="ListaGraficos">CheckedListBox que contiene todas las métriacas que se quieren incluir en el informe</param>
        public static void cargarListaCheckBox(CheckedListBox ListaGraficos)
        {
            // Función encargada de cargar las métricas en el checkBox que vamos a querer representar en nuestro informe.
            ListaGraficos.Items.Clear();
            ListaGraficos.Items.Add("Marcador");
            ListaGraficos.Items.Add("Porcentaje de error");
            ListaGraficos.Items.Add("Media y desviación");
            ListaGraficos.Items.Add("Facilidad de movimiento");
            ListaGraficos.Items.Add("Tiempo de reacción");
            ListaGraficos.Items.Add("Número de temblores");
            ListaGraficos.Items.Add("Simetría direccional x e y");
            ListaGraficos.Items.Add("Simetría velocidad y ángulo");
            ListaGraficos.Items.Add("Evolución de fuerza");
        }
    }
}
