﻿using iTextSharp.text;
using iTextSharp.text.pdf;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Windows.Forms.DataVisualization.Charting;

namespace Evolucion
{/// <summary>
/// La clase Metodos contiene los metedos encargados de tratar los datos para generar las distintas métricas,
/// En estos metodos también se puede implementar las métricas desarrolladas en un informe, se genera también el cabecero de las métricas
/// y se realiza la comprobación de la correcta selección de los ComboBox
/// </summary>
   public static class Metodos
    {
        /// <summary>
     /// Es la métrica de Marcador, gráfica tanto en la interfaz como en el PDF, el valor es la puntuación
     /// </summary>
     /// <param name="GenerarGrafico">Determina si esta métrica se incluye en el PDF</param>
     /// <param name="Informe">Es el PDF que generamos con las métricas </param>
     /// <param name="ValorTipoTerapia">Indica que tipo de terapía es la seleccionada</param>
     /// <param name="cbPaciente">ComboBox en el que seleccionamos el id del paciente </param>
     /// <param name="CbRangoTerapiaSuperior">ComboBox en el que seleccinamos la ultima terápia a representar</param>
     /// <param name="cbRangoTerapiaInferior">ComboBox en el que seleccinamos la primera terápia a representar</param>
     /// <param name="GrafTrayectoria">Es el Chart donde vamos a graficar la métrica</param>
     /// <param name="bd">Es nuestra base de datos</param>
     /// <param name="Ruta">Ruta de almacenamiento del PDF y temporalmente, de las imagenes que se incluyen en él</param>
        public static void graficaMarcador(bool GenerarGrafico, Document Informe, int ValorTipoTerapia, ComboBox cbPaciente, ComboBox CbRangoTerapiaSuperior, ComboBox cbRangoTerapiaInferior, Chart GrafTrayectoria, bbddDataContext bd, string Ruta)
        {
            try
            {
                if (ValorTipoTerapia <=13)
                {
                    //Obtenemos los valores que nos interesan de los ComboBox
                    string idPacienteSeleccionado = cbPaciente.SelectedValue.ToString();
                    string rangoSuperior = CbRangoTerapiaSuperior.SelectedValue.ToString();
                    string rangoInferior = cbRangoTerapiaInferior.SelectedValue.ToString();
                    int tipoTerapia = ValorTipoTerapia;
                    string datosGrafica="";
                    //Realizamos la consulta de los datos que nos interesan
                    var resultado = (from Terapia in bd.TerapiaBM
                                     where Terapia.IdPaciente == int.Parse(idPacienteSeleccionado) && Terapia.IdTerapia > int.Parse(rangoInferior) && Terapia.IdTerapia < int.Parse(rangoSuperior) && Terapia.TipoTerapia == tipoTerapia
                                     orderby Terapia.IdTerapia
                                     select new { Terapia.IdTerapia, Terapia.IdPaciente, Terapia.MarcadorTotal, Terapia.Fecha }).Distinct().ToList();
                    List<Series> Marcador = new List<Series>();//Lista en la que almacenamos los datos de interes y los que vamos a gráficar
                    int puntuacion = 0;
                    int contador = 0;// Contador nos indica en la terapia que nos encontramos
                    string fechaTerapia;
                    foreach (var item in resultado)
                    {
                        contador = item.IdTerapia;
                        fechaTerapia = item.Fecha.ToString();
                        if (item.MarcadorTotal == null | item.MarcadorTotal == 0)
                        {
                            // Valores no validos para medir la evolución
                        }
                        else
                        {
                            puntuacion = int.Parse((item.MarcadorTotal).ToString());
                            Marcador.Add(
                                 new Series
                                 {
                                     Fecha = fechaTerapia,
                                     Marcador = puntuacion,
                                     Terapia = contador
                                 }
                                );
                        }
                    }
                    if (Marcador.Any())
                    {
                        //Graficamos
                        GrafTrayectoria.ChartAreas.Clear();
                        GrafTrayectoria.ChartAreas.Add("Marcador");
                        GrafTrayectoria.DataSource = Marcador;
                        GrafTrayectoria.Titles.Clear();
                        GrafTrayectoria.Titles.Add("Marcador");
                        datosGrafica = "Paciente = " + idPacienteSeleccionado + " Tipo de terapia = " + tipoTerapia + " Rango = Desde " + Marcador.First().Terapia + " hasta " + contador;
                        GrafTrayectoria.Titles.Add(datosGrafica);
                        GrafTrayectoria.Series.Clear();
                        GrafTrayectoria.Series.Add("Puntuación");
                        GrafTrayectoria.Series["Puntuación"].YValueMembers = "Marcador";
                        GrafTrayectoria.Series["Puntuación"].XValueMember = "Terapia";
                        GrafTrayectoria.Series["Puntuación"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                        GrafTrayectoria.Series["Puntuación"].BorderWidth = 3;
                        GrafTrayectoria.ChartAreas["Marcador"].AxisX.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;
                        GrafTrayectoria.ChartAreas["Marcador"].AxisX.LineColor = Color.Black;
                        GrafTrayectoria.ChartAreas["Marcador"].AxisY.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;//AxisArrowStyle.Triangle;
                        GrafTrayectoria.ChartAreas["Marcador"].AxisY.LineColor = Color.Black;
                        GrafTrayectoria.ChartAreas["Marcador"].CursorX.LineWidth = 9;
                        GrafTrayectoria.ChartAreas["Marcador"].CursorY.LineWidth = 9;
                        GrafTrayectoria.ChartAreas["Marcador"].Visible = true;
                        GrafTrayectoria.ChartAreas["Marcador"].AxisX.Title = "Terapia";
                        GrafTrayectoria.ChartAreas["Marcador"].AxisY.Title = "Puntuación";
                        if (GenerarGrafico)
                        {
                            //Generamos el informe con una breve descripción, tablas de información y la gráfica
                            float SumaMediaFinal = 0;
                            float MediaFinal = 0;
                            string NombreImagen = "Maracador_Paciente_";
                            GrafTrayectoria.SaveImage(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png", System.Drawing.Imaging.ImageFormat.Png);
                            Chunk ChunkDescripcion = new Chunk("En esta métrica se va a ver la cantidad de puntos que consigue el paciente en el juego del ratón. Cada vez que el paciente atrapa al ratón recibe puntos, de forma que cuantas más veces haya atrapado al ratón, mayor puntuación tendrá. La puntuación puede variar bastante dependiendo de la dificultad.\n El índice de esta métrica son los puntos del juego.", FontFactory.GetFont("ARIAL", 11));
                            Paragraph descripcion = new Paragraph(ChunkDescripcion);
                            descripcion.Alignment = Element.ALIGN_CENTER;
                            Informe.Add(descripcion);
                            PdfPTable Tabla = new PdfPTable(4);
                            foreach (Series item in Marcador)
                            {
                                SumaMediaFinal = SumaMediaFinal + item.Marcador;

                            }
                            Tabla.AddCell("Valor");
                            Tabla.AddCell("Puntuación");
                            Tabla.AddCell("Número de terapía");
                            Tabla.AddCell("Fecha");
                            Tabla.AddCell("Primero");
                            Tabla.AddCell((Marcador.First().Marcador).ToString());
                            Tabla.AddCell((Marcador.First().Terapia).ToString());
                            Tabla.AddCell((Marcador.First().Fecha).ToString());
                            Tabla.AddCell("Último");
                            Tabla.AddCell((Marcador.Last().Marcador).ToString());
                            Tabla.AddCell((Marcador.Last().Terapia).ToString());
                            Tabla.AddCell((Marcador.Last().Fecha).ToString());
                            Marcador.Sort((x, y) => x.Marcador.CompareTo(y.Marcador));
                            Tabla.AddCell("Máximo");
                            Tabla.AddCell((Marcador.Max(x => x.Marcador)).ToString());
                            Tabla.AddCell((Marcador.Last().Terapia).ToString());
                            Tabla.AddCell((Marcador.Last().Fecha).ToString());
                            Tabla.AddCell("Mínimo");
                            Tabla.AddCell((Marcador.Min(x => x.Marcador)).ToString());
                            Tabla.AddCell((Marcador.First().Terapia).ToString());
                            Tabla.AddCell((Marcador.First().Fecha).ToString());
                            Informe.Add(new Paragraph(" "));
                            Informe.Add(Tabla);
                            MediaFinal = SumaMediaFinal / Marcador.Count();
                            Chunk MediaChunk = new Chunk(" Puntuación media: " + MediaFinal, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                            Paragraph ParrafoMeida = new Paragraph(MediaChunk);
                            ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                            Informe.Add(ParrafoMeida);
                            iTextSharp.text.Image Imagen = iTextSharp.text.Image.GetInstance(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                            Imagen.Alignment = Element.ALIGN_CENTER;
                            Imagen.ScalePercent((500 / Imagen.Width) * 100);
                            Informe.Add(Imagen);
                            System.IO.File.Delete(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                        }
                    }
                    else 
                    {
                        MessageBox.Show("No hay suficientes datos para gráficar Marcador");
                    }

                }
                //else
                //{
                //    MessageBox.Show("Marcador solo puede representarse en terapias de tipo 1");
                //}
            }
            catch (Exception ex)
            {
                MessageBox.Show("Error debido a: " + ex.Message
                   + "\r\nError debido a: " + ex.Source
                   + "\r\nError debido a: " + ex.StackTrace
                   + "\r\nError debido a: " + ex.TargetSite);
            }

        }
        /// <summary>
        /// Es la métrica del % de error cometido en los ejes,gráfica tanto en la interfaz como en el PDF, el valor es el error cometido
        /// </summary>
        /// <param name="GenerarGrafico">>Determina si esta métrica se incluye en el PDF</param>
        /// <param name="Informe">Es el PDF que generamos con las métricas</param>
        /// <param name="ValorTipoTerapia">Indica que tipo de terapía es la seleccionada</param>
        /// <param name="cbPaciente">ComboBox en el que seleccionamos el id del paciente</param>
        /// <param name="CbRangoTerapiaSuperior">ComboBox en el que seleccinamos la ultima terápia a representar</param>
        /// <param name="cbRangoTerapiaInferior">ComboBox en el que seleccinamos la primera terápia a representar</param>
        /// <param name="GrafTrayectoria">Es el Chart donde vamos a graficar la métrica</param>
        /// <param name="bd">Es nuestra base de datos</param>
        /// <param name="Ruta">Ruta de almacenamiento del PDF y temporalmente, de las imagenes que se incluyen en él</param>
        public static void graficaError(bool GenerarGrafico, Document Informe, int ValorTipoTerapia, ComboBox cbPaciente, ComboBox CbRangoTerapiaSuperior, ComboBox cbRangoTerapiaInferior, Chart GrafTrayectoria, bbddDataContext bd, string Ruta)
        {
            try
            {
                //Obtenemos los valores que nos interesan de los ComboBox
                string idPacienteSeleccionado = cbPaciente.SelectedValue.ToString();
                string rangoSuperior = CbRangoTerapiaSuperior.SelectedValue.ToString();
                string rangoInferior = cbRangoTerapiaInferior.SelectedValue.ToString();
                int tipoTerapia = ValorTipoTerapia;
                //Realizamos la consulta de los datos que nos interesan
                var resultado = (from m in bd.Muestra
                                 join Terapia in bd.TerapiaBM on m.IdTerapia equals Terapia.IdTerapia
                                 where Terapia.IdPaciente == int.Parse(idPacienteSeleccionado) && Terapia.IdTerapia > int.Parse(rangoInferior) && Terapia.IdTerapia < int.Parse(rangoSuperior) && Terapia.TipoTerapia == tipoTerapia
                                 orderby m.IdMuestra, Terapia.IdTerapia
                                 select new { Terapia.IdTerapia, m.IdMuestra, m.PosicionX, m.PosicionY, m.PuntoDeseadoX, m.PuntoDeseadoY, Terapia.IdPaciente, Terapia.Fecha }).ToList();
                //var resultado = (from Terapia in bd.TerapiaBM
                //                 join m in bd.Muestra on Terapia.IdTerapia equals m.IdTerapia
                //                 where Terapia.IdPaciente == int.Parse(idPacienteSeleccionado) && Terapia.IdTerapia > int.Parse(rangoInferior) && Terapia.IdTerapia < int.Parse(rangoSuperior) && Terapia.TipoTerapia == tipoTerapia
                //                 orderby m.IdTerapia
                //                 select new { Terapia.IdTerapia, m.IdMuestra, m.PosicionX, m.PosicionY, m.PuntoDeseadoX, m.PuntoDeseadoY, Terapia.IdPaciente, Terapia.Fecha }).Distinct().ToList();
                List<Series> Error = new List<Series>();//Lista en la que almacenamos los datos de interes y los que vamos a gráficar
                int contador = resultado.First().IdTerapia;// Contador nos indica en la terapia que nos encontramos
                string datosGrafica;
                string fechaTerapia = "";
                float puntoX = 0;
                float puntoY = 0;
                float pxf = 0;
                float pyf = 0;
                float errorX = 0;
                float errorY = 0;
                //Valores maximos yu minimos para realizar la calibración
                //Para calibrar la posición X 
                float pxo = (float)resultado.Min(x => x.PosicionX);
                float escaladoX = 1;
                float minPdx = (float)resultado.Min(x => (float)x.PuntoDeseadoX);
                float maxPdx = (float)resultado.Max(x => (float)x.PuntoDeseadoX);
                float pCalibradoX = 0;
                //Para calibrar la posición Y
                float Pyo = (float)resultado.Min(x => x.PosicionY);
                float maxPdy = (float)resultado.Max(x => (float)x.PuntoDeseadoY);
                float minPdy = (float)resultado.Min(x => (float)x.PuntoDeseadoY);
                float escaladoY = 1;
                float pCalibradoY = 0;               
                int longitud = 0;//Determina la cantidad de datos validos(tratados) en una terapia
                float sumaX = 0;
                float sumaY = 0;
                float mediaX = 0;
                float mediaY = 0;
                int k = 0;

                foreach (var item in resultado)
                {

                    if (k > 4)//Eliminamos los 5 primeros valores por un error de calibración
                    {
                        if (contador == item.IdTerapia)
                        {
                            if (tipoTerapia == 2)
                            {
                                pCalibradoX = pxo - escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - maxPdx);
                                pCalibradoY = Pyo - escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - maxPdy);
                            }
                            else
                            {
                                pCalibradoX = pxo + escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - minPdx);
                                pCalibradoY = Pyo + escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - minPdy);
                            }
                            pxf = pCalibradoX;
                            pyf = pCalibradoY;
                            fechaTerapia = item.Fecha.ToString();
                            puntoX = float.Parse((item.PosicionX).ToString());
                            puntoY = float.Parse((item.PosicionY).ToString());

                            if ((pxf != 0) | (pyf != 0) | (pyf != puntoY) | (pxf != puntoX))
                            {
                                if (pxf > 0 && pyf > 0 && puntoX > 0 && puntoY > 0)
                                {
                                    errorX = Math.Abs((pxf - puntoX) / (pxf + puntoX));
                                    errorY = Math.Abs((pyf - puntoY) / (pyf + puntoY));
                                    if (float.IsNaN(errorX) || float.IsNaN(errorY) || float.IsInfinity(errorX) || float.IsInfinity(errorY))
                                    {
                                        // si se obtiene de valores de error infinito o complejo, no se añade a la métrica.
                                    }
                                    else
                                    {
                                        if (errorX > 0 && errorY > 0 && errorX < 1 && errorY < 1)
                                        {

                                            sumaX = sumaX + errorX;
                                            sumaY = sumaY + errorY;
                                            longitud++;
                                        }
                                    }
                                }
                            }

                        }
                        else// Se ha producido un cambio de terapia, luego tratamos los datos de la terapia anterior
                        {
                            if (longitud > 2500) // Cuando en una terapia no tenemos suficientes valores no les tratamos y pasamos a la siguiente.
                            {
                                mediaX = 0;
                                mediaY = 0;
                                mediaX = 100 * sumaX / longitud;
                                mediaY = 100 * sumaY / longitud;
                                sumaX = 0;
                                sumaY = 0;
                                longitud = 0;
                                if (float.IsNaN(mediaX) || float.IsNaN(mediaY) || float.IsInfinity(mediaX) || float.IsInfinity(mediaY))
                                {
                                }
                                else
                                {
                                    if (mediaX < 100 && mediaY < 100)
                                    {
                                        Error.Add(
                                            new Series
                                            {

                                                ErrorX = mediaX,
                                                ErrorY = mediaY,
                                                Fecha = fechaTerapia,
                                                Terapia = contador
                                            }
                                            );
                                    }
                                }
                                contador=item.IdTerapia;// Para buscar la siguiente terapia.
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                            }

                            else
                            {
                                sumaX = 0;
                                sumaY = 0;
                                longitud = 0;
                                contador= item.IdTerapia;
                                k = 1;
                            }
                        }
                    }
                    k++;
                }
                Error = Error.OrderBy(u => u.Terapia).ToList();
                //Graficamos
                if (Error.Any())
                {
                    GrafTrayectoria.ChartAreas.Clear();
                    GrafTrayectoria.ChartAreas.Add("Error");
                    GrafTrayectoria.Series.Clear();
                    GrafTrayectoria.DataSource = null;
                    GrafTrayectoria.DataSource = Error;
                    GrafTrayectoria.Series.Add("% de error en X");
                    GrafTrayectoria.Series["% de error en X"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["% de error en X"].YValueMembers = "ErrorX";
                    GrafTrayectoria.Series["% de error en X"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["% de error en X"].BorderWidth = 3;
                    GrafTrayectoria.Series.Add("% de error en Y");
                    GrafTrayectoria.Series["% de error en Y"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["% de error en Y"].YValueMembers = "ErrorY";
                    GrafTrayectoria.Series["% de error en Y"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["% de error en Y"].BorderWidth = 3;
                    GrafTrayectoria.ChartAreas["Error"].AxisX.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["Error"].AxisX.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["Error"].AxisY.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;//AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["Error"].AxisY.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["Error"].CursorX.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["Error"].CursorY.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["Error"].Visible = true;
                    GrafTrayectoria.ChartAreas["Error"].AxisX.Title = "Terapias";
                    GrafTrayectoria.ChartAreas["Error"].AxisY.Title = "Error(%)";
                    GrafTrayectoria.ChartAreas["Error"].AxisX.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.ChartAreas["Error"].AxisY.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.Titles.Clear();
                    GrafTrayectoria.Titles.Add("Error Cometido");
                    datosGrafica = "Paciente = " + idPacienteSeleccionado + " Tipo de terapia = " + tipoTerapia + " Rango = Desde " + Error.First().Terapia + " hasta " + contador;
                    GrafTrayectoria.Titles.Add(datosGrafica);
                    if (GenerarGrafico)
                    {
                        //Generamos el informe con una breve descripción, tablas de información y la gráfica
                        float SumaErrorX = 0;
                        float SumaErrorY = 0;
                        float ErrorMedioX = 0;
                        float ErrorMedioY = 0;
                        string NombreImagen = "Error_Paciente_";
                        GrafTrayectoria.SaveImage(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png", System.Drawing.Imaging.ImageFormat.Png);
                        Chunk ChunkDescripcion = new Chunk("Se va a visualizar la diferencia que hay en un punto entre x e y realizados por el paciente con respecto a los puntos deseados x e y, con el objetivo de poder observar qué movimiento realiza mejor. Para ello se hace la media del punto que ha movido el paciente menos el punto deseado, entre el punto deseado tanto en x como en y.\n El índice es el error relativo en “x” y en “y”, y se medirá en %.", FontFactory.GetFont("ARIAL", 11));
                        Paragraph descripcion = new Paragraph(ChunkDescripcion);
                        descripcion.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(descripcion);
                        PdfPTable TablaErrorX = new PdfPTable(4);
                        PdfPTable TablaErrorY = new PdfPTable(4);
                        foreach (Series item in Error)
                        {
                            SumaErrorX = SumaErrorX + item.ErrorX;
                            SumaErrorY = SumaErrorY + item.ErrorY;

                        }
                        TablaErrorX.AddCell("Valor");
                        TablaErrorX.AddCell("Error en X");
                        TablaErrorX.AddCell("Número de terapía");
                        TablaErrorX.AddCell("Fecha");
                        TablaErrorX.AddCell("Primero");
                        TablaErrorX.AddCell((Error.First().ErrorX).ToString());
                        TablaErrorX.AddCell((Error.First().Terapia).ToString());
                        TablaErrorX.AddCell((Error.First().Fecha).ToString());
                        TablaErrorX.AddCell("Último");
                        TablaErrorX.AddCell((Error.Last().ErrorX).ToString());
                        TablaErrorX.AddCell((Error.Last().Terapia).ToString());
                        TablaErrorX.AddCell((Error.Last().Fecha).ToString());
                        Error.Sort((x, y) => x.ErrorX.CompareTo(y.ErrorX));
                        TablaErrorX.AddCell("Máximo");
                        TablaErrorX.AddCell((Error.Max(x => x.ErrorX)).ToString());
                        TablaErrorX.AddCell((Error.Last().Terapia).ToString());
                        TablaErrorX.AddCell((Error.Last().Fecha).ToString());
                        TablaErrorX.AddCell("Mínimo");
                        TablaErrorX.AddCell((Error.Min(x => x.ErrorX)).ToString());
                        TablaErrorX.AddCell((Error.First().Terapia).ToString());
                        TablaErrorX.AddCell((Error.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaErrorX);
                        ErrorMedioX = SumaErrorX / Error.Count();
                        Chunk MediaChunk = new Chunk(" Media de Error en X: " + ErrorMedioX, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        Paragraph ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);

                        TablaErrorY.AddCell("Valor");
                        TablaErrorY.AddCell("Error en Y");
                        TablaErrorY.AddCell("Número de terapía");
                        TablaErrorY.AddCell("Fecha");
                        TablaErrorY.AddCell("Primero");
                        TablaErrorY.AddCell((Error.First().ErrorY).ToString());
                        TablaErrorY.AddCell((Error.First().Terapia).ToString());
                        TablaErrorY.AddCell((Error.First().Fecha).ToString());
                        TablaErrorY.AddCell("Último");
                        TablaErrorY.AddCell((Error.Last().ErrorY).ToString());
                        TablaErrorY.AddCell((Error.Last().Terapia).ToString());
                        TablaErrorY.AddCell((Error.Last().Fecha).ToString());
                        Error.Sort((x, y) => x.ErrorY.CompareTo(y.ErrorY));
                        TablaErrorY.AddCell("Máximo");
                        TablaErrorY.AddCell((Error.Max(x => x.ErrorY)).ToString());
                        TablaErrorY.AddCell((Error.Last().Terapia).ToString());
                        TablaErrorY.AddCell((Error.Last().Fecha).ToString());
                        TablaErrorY.AddCell("Mínimo");
                        TablaErrorY.AddCell((Error.Min(x => x.ErrorY)).ToString());
                        TablaErrorY.AddCell((Error.First().Terapia).ToString());
                        TablaErrorY.AddCell((Error.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaErrorY);
                        ErrorMedioY = SumaErrorY / Error.Count();
                        MediaChunk = new Chunk(" Media de Error en Y: " + ErrorMedioY, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);
                        iTextSharp.text.Image Imagen = iTextSharp.text.Image.GetInstance(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                        Imagen.Alignment = Element.ALIGN_CENTER;
                        Imagen.ScalePercent((500 / Imagen.Width) * 100);
                        Informe.Add(Imagen);
                        System.IO.File.Delete(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                    }
                }
                else
                {
                    MessageBox.Show("No hay suficientes datos para gráficar el porcentaje de error");
                }
                }
            catch (Exception ex)
            {
                MessageBox.Show("Error debido a: " + ex.Message
                   + "\r\nError debido a: " + ex.Source
                   + "\r\nError debido a: " + ex.StackTrace
                   + "\r\nError debido a: " + ex.TargetSite);
            }

        }
        /// <summary>
        /// Es la métrica de media y desviación, gráfica tanto en la interfaz como en el PDF, Los valores son la media y la desviación de los valores recorridos menos los deseados
        /// </summary>
        /// <param name="GenerarGrafico">Determina si esta métrica se incluye en el PDF</param>
        /// <param name="Informe">Es el PDF que generamos con las métricas</param>
        /// <param name="ValorTipoTerapia">Indica que tipo de terapía es la seleccionada</param>
        /// <param name="cbPaciente">ComboBox en el que seleccionamos el id del paciente</param>
        /// <param name="CbRangoTerapiaSuperior">ComboBox en el que seleccinamos la ultima terápia a representar</param>
        /// <param name="cbRangoTerapiaInferior">ComboBox en el que seleccinamos la primera terápia a representar</param>
        /// <param name="GrafTrayectoria">Es el Chart donde vamos a graficar la métrica</param>
        /// <param name="bd">Es nuestra base de datos</param>
        /// <param name="Ruta">Ruta de almacenamiento del PDF y temporalmente, de las imagenes que se incluyen en él</param>
        public static void graficaMedia(bool GenerarGrafico, Document Informe, int ValorTipoTerapia, ComboBox cbPaciente, ComboBox CbRangoTerapiaSuperior, ComboBox cbRangoTerapiaInferior, Chart GrafTrayectoria, bbddDataContext bd, string Ruta)
        {
            try
            {
                //Obtenemos los valores que nos interesan de los ComboBox
                string idPacienteSeleccionado = cbPaciente.SelectedValue.ToString();
                string rangoSuperior = CbRangoTerapiaSuperior.SelectedValue.ToString();
                string rangoInferior = cbRangoTerapiaInferior.SelectedValue.ToString();
                int tipoTerapia = ValorTipoTerapia;
                //Realizamos la consulta de los datos que nos interesan
                var resultado = (from consulta in bd.Muestra
                                 join Terapia in bd.TerapiaBM on consulta.IdTerapia equals Terapia.IdTerapia
                                 where Terapia.IdPaciente == int.Parse(idPacienteSeleccionado) && Terapia.IdTerapia > int.Parse(rangoInferior) && Terapia.IdTerapia < int.Parse(rangoSuperior) && Terapia.TipoTerapia == tipoTerapia
                                 orderby consulta.IdMuestra
                                 select new { Terapia.IdTerapia, consulta.IdMuestra, consulta.PosicionX, consulta.PosicionY, consulta.PuntoDeseadoX, consulta.PuntoDeseadoY, Terapia.IdPaciente, Terapia.Fecha }).ToList();
                resultado = resultado.OrderBy(o => o.IdTerapia).ToList();
                List<Series> mediaDesviacion = new List<Series>();//Lista en la que almacenamos los datos de interes y los que vamos a gráficar
                string datosGrafica;
                string FechaTerapia = "";
                int contador = resultado.First().IdTerapia;// Contador nos indica en la terapia que nos encontramos
                float puntoX = 0;
                float puntoY = 0;
                //Valores maximos yu minimos para realizar la calibración
                //Para calibrar la posición X 
                float pxo = (float)resultado.Min(x => x.PosicionX);
                float escaladoX = 1;
                float minPdx = (float)resultado.Min(x => (float)x.PuntoDeseadoX);
                float maxPdx = (float)resultado.Max(x => (float)x.PuntoDeseadoX);
                float pCalibradoX = 0;
                //Para calibrar la posición Y
                float pyo = (float)resultado.Min(x => x.PosicionY);
                float maxPdy = (float)resultado.Max(x => (float)x.PuntoDeseadoY);
                float minPdy = (float)resultado.Min(x => (float)x.PuntoDeseadoY);
                float escaladoY = 1;
                float pCalibradoY = 0;
                float pxf = 0;
                float pyf = 0;
                int longitud = 0;//Determina la cantidad de datos validos(tratados) en una terapia
                float sumaMedia = 0;
                float sumaDesviacion = 0;
                float sumaCuadratica = 0;
                float media = 0;
                float desviacion = 0;
                List<double> valor = new List<double>();
                int k = 0;
                foreach (var item in resultado)
                {
                    if (k > 4)//Eliminamos los 5 primeros valores por un error de calibración
                    {
                        if (contador == item.IdTerapia)
                        {
                            FechaTerapia = item.Fecha.ToString();
                            puntoX = float.Parse((item.PosicionX).ToString());
                            puntoY = float.Parse((item.PosicionY).ToString());
                            if (tipoTerapia == 2)
                            {
                                pCalibradoX = pxo - escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - maxPdx);
                                pCalibradoY = pyo - escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - maxPdy);
                            }
                            else
                            {
                                pCalibradoX = pxo + escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - minPdx);
                                pCalibradoY = pyo + escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - minPdy);
                            }
                            pxf = pCalibradoX;
                            pyf = pCalibradoY;
                            sumaCuadratica =(float)Math.Sqrt(Math.Pow((puntoX - pxf), 2) + Math.Pow((puntoY - pyf), 2));
                            sumaMedia = sumaMedia + sumaCuadratica;
                            valor.Add(sumaCuadratica);
                            longitud++;

                        }
                        else// Se ha producido un cambio de terapia, luego tratamos los datos de la terapia anterior
                        {
                            if (longitud > 2500) // Cuando en una terapia no tenemos suficientes valores no les tratamos y pasamos a la siguiente.
                            {
                                media = 0;
                                media = sumaMedia / longitud;
                                sumaMedia = 0;
                                sumaDesviacion = 0;
                                for (int i = 0; i < longitud; i++)
                                {
                                    sumaDesviacion = (float)(sumaDesviacion + Math.Pow((valor[i] - media), 2));
                                }
                                desviacion = (float)(Math.Sqrt(sumaDesviacion / (longitud - 1)));
                                mediaDesviacion.Add(
                                    new Series
                                    {
                                        Media = media,
                                        Desviacion = desviacion,
                                        Fecha = FechaTerapia,
                                        Terapia = contador
                                    });                                
                                longitud = 0;
                                contador=item.IdTerapia;
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                            }

                            else
                            {
                                //MessageBox.Show("longitud: " + longitud + "contador: " + contador + "actual: " + item.IdTerapia);
                                longitud = 0;
                                contador=item.IdTerapia;
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                            }
                        }
                    }
                    k++;
                }
                mediaDesviacion = mediaDesviacion.OrderBy(u => u.Terapia).ToList();
                if (mediaDesviacion.Any())
                {
                    //Graficamos
                    GrafTrayectoria.ChartAreas.Clear();
                    GrafTrayectoria.ChartAreas.Add("media");
                    GrafTrayectoria.Series.Clear();
                    GrafTrayectoria.DataSource = null;
                    GrafTrayectoria.DataSource = mediaDesviacion;
                    GrafTrayectoria.Series.Add("Distancia media de las posiciones realizadas a posiciones deseadas");
                    GrafTrayectoria.Series["Distancia media de las posiciones realizadas a posiciones deseadas"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Distancia media de las posiciones realizadas a posiciones deseadas"].YValueMembers = "Media";
                    GrafTrayectoria.Series["Distancia media de las posiciones realizadas a posiciones deseadas"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Distancia media de las posiciones realizadas a posiciones deseadas"].BorderWidth = 3;
                    GrafTrayectoria.Series.Add("Desviación Estandar de las posiciones realizadas a posiciones deseadas");
                    GrafTrayectoria.Series["Desviación Estandar de las posiciones realizadas a posiciones deseadas"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Desviación Estandar de las posiciones realizadas a posiciones deseadas"].YValueMembers = "Desviacion";
                    GrafTrayectoria.Series["Desviación Estandar de las posiciones realizadas a posiciones deseadas"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Desviación Estandar de las posiciones realizadas a posiciones deseadas"].BorderWidth = 3;
                    GrafTrayectoria.ChartAreas["media"].AxisX.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["media"].AxisX.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["media"].AxisY.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;//AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["media"].AxisY.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["media"].CursorX.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["media"].CursorY.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["media"].Visible = true;
                    GrafTrayectoria.ChartAreas["media"].AxisX.Title = "Terapias";
                    GrafTrayectoria.ChartAreas["media"].AxisY.Title = "Distancia(mm)";
                    GrafTrayectoria.ChartAreas["media"].AxisX.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.ChartAreas["media"].AxisY.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.Titles.Clear();
                    GrafTrayectoria.Titles.Add("Media y desviación");
                    datosGrafica = "Paciente = " + idPacienteSeleccionado + " Tipo de terapia = " + tipoTerapia + " Rango = Desde " + mediaDesviacion.First().Terapia + " hasta " + contador;
                    GrafTrayectoria.Titles.Add(datosGrafica);
                    if (GenerarGrafico)
                    {
                        //Generamos el informe con una breve descripción, tablas de información y la gráfica
                        float SumaMediaTotal = 0;
                        float SumaDesviacionTotal = 0;
                        float MediaTotal = 0;
                        float DesviacionTotal = 0;
                        string NombreImagen = "Media_Desviacion_Paciente_";
                        GrafTrayectoria.SaveImage(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png", System.Drawing.Imaging.ImageFormat.Png);
                        Chunk ChunkDescripcion = new Chunk("Media: es la suma de la diferencia de los puntos geométricos en el plano en x y en y recorridos por el paciente con respecto a los puntos deseados, dividido entre el número de puntos recorridos.\n Desviación típica: es el sumatorio de la raíz cuadrada del cuadrado de la diferencia de los puntos geométricos en el plano en x y en y recorridos por el paciente con respecto a los puntos deseados, dividido entre el número de puntos recorridos.\n Los índices que tendremos serán la media y la desviación típica de los puntos de cada terapia.", FontFactory.GetFont("ARIAL", 11));
                        Paragraph descripcion = new Paragraph(ChunkDescripcion);
                        descripcion.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(descripcion);
                        PdfPTable TablaMedia = new PdfPTable(4);
                        PdfPTable TablaDesviacion = new PdfPTable(4);
                        foreach (Series item in mediaDesviacion)
                        {
                            SumaMediaTotal = SumaMediaTotal + item.Media;
                            SumaDesviacionTotal = SumaDesviacionTotal + item.Desviacion;

                        }
                        TablaMedia.AddCell("Valor");
                        TablaMedia.AddCell("media");
                        TablaMedia.AddCell("Número de terapía");
                        TablaMedia.AddCell("Fecha");
                        TablaMedia.AddCell("Primero");
                        TablaMedia.AddCell((mediaDesviacion.First().Media).ToString());
                        TablaMedia.AddCell((mediaDesviacion.First().Terapia).ToString());
                        TablaMedia.AddCell((mediaDesviacion.First().Fecha).ToString());
                        TablaMedia.AddCell("Último");
                        TablaMedia.AddCell((mediaDesviacion.Last().Media).ToString());
                        TablaMedia.AddCell((mediaDesviacion.Last().Terapia).ToString());
                        TablaMedia.AddCell((mediaDesviacion.Last().Fecha).ToString());
                        mediaDesviacion.Sort((x, y) => x.Media.CompareTo(y.Media));
                        TablaMedia.AddCell("Máximo");
                        TablaMedia.AddCell((mediaDesviacion.Max(x => x.Media)).ToString());
                        TablaMedia.AddCell((mediaDesviacion.Last().Terapia).ToString());
                        TablaMedia.AddCell((mediaDesviacion.Last().Fecha).ToString());
                        TablaMedia.AddCell("Mínimo");
                        TablaMedia.AddCell((mediaDesviacion.Min(x => x.Media)).ToString());
                        TablaMedia.AddCell((mediaDesviacion.First().Terapia).ToString());
                        TablaMedia.AddCell((mediaDesviacion.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaMedia);
                        MediaTotal = SumaMediaTotal / mediaDesviacion.Count();
                        Chunk MediaChunk = new Chunk(" Media: " + MediaTotal, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        Paragraph ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);

                        TablaDesviacion.AddCell("Valor");
                        TablaDesviacion.AddCell("Desviación");
                        TablaDesviacion.AddCell("Número de terapía");
                        TablaDesviacion.AddCell("Fecha");
                        TablaDesviacion.AddCell("Primero");
                        TablaDesviacion.AddCell((mediaDesviacion.First().Desviacion).ToString());
                        TablaDesviacion.AddCell((mediaDesviacion.First().Terapia).ToString());
                        TablaDesviacion.AddCell((mediaDesviacion.First().Fecha).ToString());
                        TablaDesviacion.AddCell("Último");
                        TablaDesviacion.AddCell((mediaDesviacion.Last().Desviacion).ToString());
                        TablaDesviacion.AddCell((mediaDesviacion.Last().Terapia).ToString());
                        TablaDesviacion.AddCell((mediaDesviacion.Last().Fecha).ToString());
                        mediaDesviacion.Sort((x, y) => x.Desviacion.CompareTo(y.Desviacion));
                        TablaDesviacion.AddCell("Máximo");
                        TablaDesviacion.AddCell((mediaDesviacion.Max(x => x.Desviacion)).ToString());
                        TablaDesviacion.AddCell((mediaDesviacion.Last().Terapia).ToString());
                        TablaDesviacion.AddCell((mediaDesviacion.Last().Fecha).ToString());
                        TablaDesviacion.AddCell("Mínimo");
                        TablaDesviacion.AddCell((mediaDesviacion.Min(x => x.Desviacion)).ToString());
                        TablaDesviacion.AddCell((mediaDesviacion.First().Terapia).ToString());
                        TablaDesviacion.AddCell((mediaDesviacion.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaDesviacion);
                        DesviacionTotal = SumaDesviacionTotal / mediaDesviacion.Count();
                        MediaChunk = new Chunk(" Media de desviación: " + DesviacionTotal, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);
                        iTextSharp.text.Image Imagen = iTextSharp.text.Image.GetInstance(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                        Imagen.Alignment = Element.ALIGN_CENTER;
                        Imagen.ScalePercent((500 / Imagen.Width) * 100);
                        Informe.Add(Imagen);
                        System.IO.File.Delete(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                    }
                }
                else
                {
                    MessageBox.Show("No hay suficientes datos para gráficar la media y la desviación");
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("Error debido a: " + ex.Message
                   + "\r\nError debido a: " + ex.Source
                   + "\r\nError debido a: " + ex.StackTrace
                   + "\r\nError debido a: " + ex.TargetSite);
            }

        }
        /// <summary>
        /// Es la métrica de la Facilidad de movimiento, gráfica tanto en la interfaz como en el PDF, el valor es la media de las velocidades
        /// </summary>
        /// <param name="GenerarGrafico">Determina si esta métrica se incluye en el PDF</param>
        /// <param name="Informe">Es el PDF que generamos con las métricas</param>
        /// <param name="ValorTipoTerapia">Indica que tipo de terapía es la seleccionada</param>
        /// <param name="cbPaciente">ComboBox en el que seleccionamos el id del paciente</param>
        /// <param name="CbRangoTerapiaSuperior">ComboBox en el que seleccinamos la ultima terápia a representar</param>
        /// <param name="cbRangoTerapiaInferior">ComboBox en el que seleccinamos la primera terápia a representar</param>
        /// <param name="GrafTrayectoria">Es el Chart donde vamos a graficar la métrica a representar</param>
        /// <param name="bd">Es nuestra base de datos</param>
        /// <param name="Ruta">Ruta de almacenamiento del PDF y temporalmente, de las imagenes que se incluyen en él</param>
        public static void graficaMediaVelocidad(bool GenerarGrafico, Document Informe, int ValorTipoTerapia, ComboBox cbPaciente, ComboBox CbRangoTerapiaSuperior, ComboBox cbRangoTerapiaInferior, Chart GrafTrayectoria, bbddDataContext bd, string Ruta)
        {
            try
            {
                //Obtenemos los valores que nos interesan de los ComboBox
                string idPacienteSeleccionado = cbPaciente.SelectedValue.ToString();
                string rangoSuperior = CbRangoTerapiaSuperior.SelectedValue.ToString();
                int tipoTerapia = ValorTipoTerapia;
                string rangoInferior = cbRangoTerapiaInferior.SelectedValue.ToString();
                //Realizamos la consulta de los datos que nos interesan
                var resultado = from Terapia in bd.TerapiaBM
                                join m in bd.Muestra on Terapia.IdTerapia equals m.IdTerapia
                                orderby m.IdMuestra, Terapia.IdTerapia
                                where Terapia.IdPaciente == int.Parse(idPacienteSeleccionado) && Terapia.IdTerapia > int.Parse(rangoInferior) && Terapia.IdTerapia < int.Parse(rangoSuperior) && Terapia.TipoTerapia == tipoTerapia
                                select new { Terapia.IdTerapia, m.IdMuestra, m.VelocidadX, m.VelocidadY, Terapia.IdPaciente, Terapia.Fecha };
                int contador = resultado.First().IdTerapia;// Contador nos indica en la terapia que nos encontramos
                string datosGrafica;
                string fechaTerapia = "";
                float velocidadX = 0;
                float velocidadY = 0;
                int longitud = 0;//Determina la cantidad de datos validos(tratados) en una terapia
                float sumaMediaVelocidad = 0;
                float media = 0;
                int k = 0;
                List<Series> mediaVelocidad = new List<Series>();//Lista en la que almacenamos los datos de interes y los que vamos a gráficar
                foreach (var item in resultado)
                {
                    if (k > 4)//Eliminamos los 5 primeros valores por un error de calibración
                    {
                        if (contador == item.IdTerapia)
                        {
                            fechaTerapia = item.Fecha.ToString();
                            velocidadX = float.Parse((item.VelocidadX).ToString());
                            velocidadY = float.Parse((item.VelocidadY).ToString());
                            sumaMediaVelocidad = (float)(sumaMediaVelocidad + Math.Sqrt(Math.Pow((velocidadY / 1000), 2) + Math.Pow((velocidadX / 1000), 2)));
                            longitud++;
                        }

                        else// Se ha producido un cambio de terapia, luego tratamos los datos de la terapia anterior
                        {
                            if (longitud > 2500) // Cuando en una terapia no tenemos suficientes valores no les tratamos y pasamos a la siguiente.
                            {
                                media = 0;
                                media = sumaMediaVelocidad / longitud;
                                sumaMediaVelocidad = 0;
                                mediaVelocidad.Add(
                                    new Series
                                    {
                                        Fecha = fechaTerapia,
                                        Media = media,
                                        Terapia = contador

                                    });
                                contador=item.IdTerapia;
                                longitud = 0;
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                            }
                            else
                            {
                                sumaMediaVelocidad = 0;
                                contador= item.IdTerapia; ;
                                longitud = 0;
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                            }
                        }

                    }
                    k++;
                }
                mediaVelocidad = mediaVelocidad.OrderBy(u => u.Terapia).ToList();
                if (mediaVelocidad.Any())
                {
                    //Graficamos
                    GrafTrayectoria.ChartAreas.Clear();
                    GrafTrayectoria.ChartAreas.Add("Velocidad");
                    GrafTrayectoria.Series.Clear();
                    GrafTrayectoria.DataSource = null;
                    GrafTrayectoria.DataSource = mediaVelocidad;
                    GrafTrayectoria.Series.Add("media de la velocidad del paciente");
                    GrafTrayectoria.Series["media de la velocidad del paciente"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["media de la velocidad del paciente"].YValueMembers = "media";
                    GrafTrayectoria.Series["media de la velocidad del paciente"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["media de la velocidad del paciente"].BorderWidth = 3;
                    GrafTrayectoria.ChartAreas["Velocidad"].AxisX.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["Velocidad"].AxisX.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["Velocidad"].AxisY.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;//AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["Velocidad"].AxisY.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["Velocidad"].CursorX.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["Velocidad"].CursorY.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["Velocidad"].Visible = true;
                    GrafTrayectoria.ChartAreas["Velocidad"].AxisX.Title = "Terapias";
                    GrafTrayectoria.ChartAreas["Velocidad"].AxisY.Title = "Velocidad(m/s)";
                    GrafTrayectoria.ChartAreas["Velocidad"].AxisX.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.ChartAreas["Velocidad"].AxisY.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.Titles.Clear();
                    GrafTrayectoria.Titles.Add("Facilidad de movimiento");
                    datosGrafica = "Paciente = " + idPacienteSeleccionado + " Tipo de terapia = " + tipoTerapia + " Rango = Desde " + mediaVelocidad.First().Terapia + " hasta " + contador;
                    GrafTrayectoria.Titles.Add(datosGrafica);
                    if (GenerarGrafico)
                    {
                        //Generamos el informe con una breve descripción, tablas de información y la gráfica
                        float SumaMediaFinal = 0;
                        float MediaFinal = 0;
                        string NombreImagen = "Velocidad_Paciente_";
                        GrafTrayectoria.SaveImage(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png", System.Drawing.Imaging.ImageFormat.Png);
                        Chunk ChunkDescripcion = new Chunk("Según varios estudios, la facilidad de movimiento se puede relacionar con a velocidad, de forma que cuanto más rápido tengas las capacidad de moverte, menos esfuerzo te costará realizar la tarea, y por lo tanto tendrás una mayor facilidad de movimiento.\nEl índice será la velocidad media medida en m/s.", FontFactory.GetFont("ARIAL", 11));
                        Paragraph descripcion = new Paragraph(ChunkDescripcion);
                        descripcion.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(descripcion);
                        PdfPTable TablaVelocidad = new PdfPTable(4);
                        foreach (Series item in mediaVelocidad)
                        {
                            SumaMediaFinal = SumaMediaFinal + item.Media;

                        }
                        TablaVelocidad.AddCell("Valor");
                        TablaVelocidad.AddCell("Velocidad");
                        TablaVelocidad.AddCell("Número de terapía");
                        TablaVelocidad.AddCell("Fecha");
                        TablaVelocidad.AddCell("Primero");
                        TablaVelocidad.AddCell((mediaVelocidad.First().Media).ToString());
                        TablaVelocidad.AddCell((mediaVelocidad.First().Terapia).ToString());
                        TablaVelocidad.AddCell((mediaVelocidad.First().Fecha).ToString());
                        TablaVelocidad.AddCell("Último");
                        TablaVelocidad.AddCell((mediaVelocidad.Last().Media).ToString());
                        TablaVelocidad.AddCell((mediaVelocidad.Last().Terapia).ToString());
                        TablaVelocidad.AddCell((mediaVelocidad.Last().Fecha).ToString());
                        mediaVelocidad.Sort((x, y) => x.Media.CompareTo(y.Media));
                        TablaVelocidad.AddCell("Máximo");
                        TablaVelocidad.AddCell((mediaVelocidad.Max(x => x.Media)).ToString());
                        TablaVelocidad.AddCell((mediaVelocidad.Last().Terapia).ToString());
                        TablaVelocidad.AddCell((mediaVelocidad.Last().Fecha).ToString());
                        TablaVelocidad.AddCell("Mínimo");
                        TablaVelocidad.AddCell((mediaVelocidad.Min(x => x.Media)).ToString());
                        TablaVelocidad.AddCell((mediaVelocidad.First().Terapia).ToString());
                        TablaVelocidad.AddCell((mediaVelocidad.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaVelocidad);
                        MediaFinal = SumaMediaFinal / mediaVelocidad.Count();
                        Chunk MediaChunk = new Chunk("Velocidad media: " + MediaFinal, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        Paragraph ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);
                        iTextSharp.text.Image Imagen = iTextSharp.text.Image.GetInstance(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                        Imagen.Alignment = Element.ALIGN_CENTER;
                        Imagen.ScalePercent((500 / Imagen.Width) * 100);
                        Informe.Add(Imagen);
                        System.IO.File.Delete(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                    }
                }
                else
                {
                    MessageBox.Show("No hay suficientes datos para gráficar la facilidad de movimiento");
                }

            }
            catch (Exception ex)
            {
                MessageBox.Show("Error debido a: " + ex.Message
                   + "\r\nError debido a: " + ex.Source
                   + "\r\nError debido a: " + ex.StackTrace
                   + "\r\nError debido a: " + ex.TargetSite);
            }

        }
        /// <summary>
        /// Es la métrica del Tiempo de reacción, gráfica tanto en la interfaz como en el PDF, el valor es el tiempo que tarda en reorientar
        /// </summary>
        /// <param name="GenerarGrafico">Determina si esta métrica se incluye en el PDF</param>
        /// <param name="Informe">Es el PDF que generamos con las métricas</param>
        /// <param name="ValorTipoTerapia">Indica que tipo de terapía es la seleccionada</param>
        /// <param name="cbPaciente">ComboBox en el que seleccionamos el id del paciente</param>
        /// <param name="CbRangoTerapiaSuperior">ComboBox en el que seleccinamos la ultima terápia a representar</param>
        /// <param name="cbRangoTerapiaInferior">ComboBox en el que seleccinamos la primera terápia a representar</param>
        /// <param name="GrafTrayectoria">Es el Chart donde vamos a graficar la métrica </param>
        /// <param name="bd">Es nuestra base de datos</param>
        /// <param name="Ruta">Ruta de almacenamiento del PDF y temporalmente, de las imagenes que se incluyen en él</param>
        public static void graficaTiempoReacion(bool GenerarGrafico, Document Informe, int ValorTipoTerapia, ComboBox cbPaciente, ComboBox CbRangoTerapiaSuperior, ComboBox cbRangoTerapiaInferior, Chart GrafTrayectoria, bbddDataContext bd, string Ruta)
        {           
            try
            {
                //Obtenemos los valores que nos interesan de los ComboBox
                string idPacienteSeleccionado = cbPaciente.SelectedValue.ToString();
                string rangoSuperior = CbRangoTerapiaSuperior.SelectedValue.ToString();
                string rangoInferior = cbRangoTerapiaInferior.SelectedValue.ToString();
                int tipoTerapia = ValorTipoTerapia;
                //Realizamos la consulta de los datos que nos interesan
                var resultado = (from Terapia in bd.TerapiaBM
                                 join consulta in bd.Muestra on Terapia.IdTerapia equals consulta.IdTerapia
                                 where Terapia.IdPaciente == int.Parse(idPacienteSeleccionado) && Terapia.IdTerapia > int.Parse(rangoInferior) && Terapia.IdTerapia < int.Parse(rangoSuperior) && Terapia.TipoTerapia == tipoTerapia
                                 orderby consulta.IdTerapia
                                 select new { Terapia.IdTerapia, consulta.IdMuestra, consulta.PosicionX, consulta.PosicionY, consulta.PuntoDeseadoX, consulta.PuntoDeseadoY, consulta.Tiempo, Terapia.IdPaciente, Terapia.Fecha }).Distinct().ToList();
                resultado = resultado.OrderBy(o => o.IdTerapia).ToList();
                int contador = resultado.First().IdTerapia;// Contador nos indica en la terapia que nos encontramos
                string datosGrafica;
                string FechaTerapia = "";
                List<Series> tiempoReaccion = new List<Series>();//Lista en la que almacenamos los datos de interes y los que vamos a gráficar
                List<float> puntoX = new List<float>();
                List<float> puntoY = new List<float>();
                List<float> puntoXf = new List<float>();
                List<float> puntoYf = new List<float>();
                List<float> listaTiempo = new List<float>();
                string[] tiempoSeparado;
                float Px = 0;
                float Py = 0;
                //Valores maximos yu minimos para realizar la calibración
                //Para calibrar la posición X 
                float pxo = (float)resultado.Min(x => x.PosicionX);
                float escaladoX = 1;
                float minPdx = (float)resultado.Min(x => (float)x.PuntoDeseadoX);
                float maxPdx = (float)resultado.Max(x => (float)x.PuntoDeseadoX);
                float PcalibradoX = 0;
                //Para calibrar la posición Y
                float pyo = (float)resultado.Min(x => x.PosicionY);
                float maxPdy = (float)resultado.Max(x => (float)x.PuntoDeseadoY);
                float minPdy = (float)resultado.Min(x => (float)x.PuntoDeseadoY);
                float escaladoY = 1;
                float pCalibradoY = 0;
                float pxf = 0;
                float pyf = 0;
                int longitud = 0;//Determina la cantidad de datos validos(tratados) en una terapia
                double s1 = 0;
                double s2 = 0;
                double s3 = 0;
                double tiempo = 0;
                float dpxt = 0;// Nos vas a determinar la orientación del eje x
                float dpyt = 0;// Nos va a determinar la orientación del eje y                
                int semaforo = 0;//Le utilizamos para establer el orden desde que hay una diferencia de orientación hasta que se vuelver a orientar
                float tiempoFinal = 0;
                float tiempoInicial = 0;//Tiempo en el que comienza la distinta orientacion
                float sumaTiempo = 0;//Tiempo en el que consigue orientarse
                float reaccion = 0;
                int longitudTiempo = 0;
                int k = 0;
                foreach (var item in resultado)
                {
                    if (k > 4)//Eliminamos los 5 primeros valores por un error de calibración
                    {
                        if (contador == item.IdTerapia)
                        {
                            FechaTerapia = item.Fecha.ToString();
                            tiempoSeparado = (item.Tiempo).Split(':');
                            s1 = double.Parse(tiempoSeparado[0]) * 3600;
                            s2 = double.Parse(tiempoSeparado[1]) * 60;
                            s3 = double.Parse(tiempoSeparado[2]);
                            tiempo = s1 + s2 + s3 / 10000000;
                            listaTiempo.Add((float)tiempo);
                            Px = float.Parse((item.PosicionX).ToString());
                            Py = float.Parse((item.PosicionY).ToString());
                            if (tipoTerapia == 2)
                            {
                                PcalibradoX = pxo - escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - maxPdx);
                                pCalibradoY = pyo - escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - maxPdy);
                            }
                            else
                            {
                                PcalibradoX = pxo + escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - minPdx);
                                pCalibradoY = pyo + escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - minPdy);
                            }
                            pxf = PcalibradoX;
                            pyf = pCalibradoY;
                            puntoX.Add(Px);
                            puntoY.Add(Py);
                            puntoYf.Add(pyf);
                            puntoXf.Add(pxf);
                            longitud++;

                        }
                        else// Se ha producido un cambio de terapia, luego tratamos los datos de la terapia anterior
                        {
                            if (longitud > 500) // Cuando en una terapia no tenemos suficientes valores no les tratamos y pasamos a la siguiente.
                            {
                                for (int i = 0; i < longitud - 1; i++)
                                {
                                    dpxt = (puntoX[i + 1] - puntoX[i]) * (puntoXf[i + 1] - puntoXf[i]);// si es negativo distinta orientación en x
                                    dpyt = (puntoY[i + 1] - puntoY[i]) * (puntoYf[i + 1] - puntoYf[i]);// si es negativo distinta orientación en y

                                    if (dpxt> 0 & dpyt>0)// Misma orientación
                                    {

                                        if (semaforo == 1)
                                        {
                                            semaforo = 0;
                                            tiempoFinal = listaTiempo[i];
                                            if ((tiempoFinal - tiempoInicial) < 10 && !float.IsNaN(tiempoFinal - tiempoInicial)&& (tiempoFinal - tiempoInicial)>0)//filtro de falso tiempo de 
                                            {
                                                sumaTiempo = sumaTiempo + tiempoFinal - tiempoInicial;
                                            }
                                            longitudTiempo++;

                                        }
                                    }
                                    else if (dpxt < 0 || dpyt < 0)// distinta orientación
                                    {
                                        if (semaforo == 0)
                                        {
                                            semaforo = 1;
                                            tiempoInicial = listaTiempo[i];
                                        }
                                    }

                                }
                                reaccion = sumaTiempo / longitudTiempo;
                                if (!float.IsNaN(reaccion))
                                {
                                    tiempoReaccion.Add(
                                    new Series
                                    {
                                        Media = (float)reaccion,
                                        Fecha = FechaTerapia,
                                        Terapia = contador
                                    });
                                }
                                puntoXf.Clear();
                                puntoX.Clear();
                                puntoY.Clear();
                                puntoYf.Clear();
                                contador = item.IdTerapia;
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                                longitud = 0;
                                sumaTiempo = 0;
                                longitudTiempo = 0;
                                tiempoInicial = 0;
                                tiempoFinal = 0;
                            }

                            else
                            {
                                puntoXf.Clear();
                                puntoX.Clear();
                                puntoY.Clear();
                                puntoYf.Clear();
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                                longitud = 0;
                                contador=item.IdTerapia;
                                sumaTiempo = 0;
                                longitudTiempo = 0;
                                tiempoInicial = 0;
                                tiempoFinal = 0;
                            }
                        }
                    }
                    k++;
                }
                tiempoReaccion = tiempoReaccion.OrderBy(o => o.Terapia).ToList();
                if (tiempoReaccion.Any())
                {
                    //Graficamos
                    GrafTrayectoria.ChartAreas.Clear();
                    GrafTrayectoria.ChartAreas.Add("tiempoReaccion");
                    GrafTrayectoria.Series.Clear();
                    GrafTrayectoria.DataSource = null;
                    GrafTrayectoria.DataSource = tiempoReaccion;
                    GrafTrayectoria.Series.Add("Tiempo de reacción");
                    GrafTrayectoria.Series["Tiempo de reacción"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Tiempo de reacción"].YValueMembers = "media";
                    GrafTrayectoria.Series["Tiempo de reacción"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Tiempo de reacción"].BorderWidth = 3;
                    GrafTrayectoria.ChartAreas["tiempoReaccion"].AxisX.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["tiempoReaccion"].AxisX.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["tiempoReaccion"].AxisY.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;//AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["tiempoReaccion"].AxisY.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["tiempoReaccion"].CursorX.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["tiempoReaccion"].CursorY.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["tiempoReaccion"].Visible = true;
                    GrafTrayectoria.ChartAreas["tiempoReaccion"].AxisX.Title = "Terapias";
                    GrafTrayectoria.ChartAreas["tiempoReaccion"].AxisY.Title = "Tiempo de reaccion(s)";
                    GrafTrayectoria.ChartAreas["tiempoReaccion"].AxisX.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.ChartAreas["tiempoReaccion"].AxisY.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.Titles.Clear();
                    GrafTrayectoria.Titles.Add("Tiempo de reacción");
                    datosGrafica = "Paciente = " + idPacienteSeleccionado + " Tipo de terapia = " + tipoTerapia + " Rango = Desde " + tiempoReaccion.First().Terapia + " hasta " + contador;
                    GrafTrayectoria.Titles.Add(datosGrafica);
                    if (GenerarGrafico)
                    {
                        //Generamos el informe con una breve descripción, tablas de información y la gráfica
                        float SumaMediaFinal = 0;
                        float MediaFinal = 0;
                        string NombreImagen = "Tiempo_de_Reaccion_Paciente_";
                        GrafTrayectoria.SaveImage(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png", System.Drawing.Imaging.ImageFormat.Png);
                        Chunk ChunkDescripcion = new Chunk("Se denomina tiempo de reacción al tiempo que pasa desde que en la trayectoria deseada se produce un cambio de sentido hasta que en la trayectoria del robot se produce ese cambio de sentido también. Para ello se resta el tiempo en el que se produjo el cambio en el robot menos el tiempo en el que se produzco el cambio en el sentido deseado. \nEl índice que se obtiene será el tiempo de reacción y se medirá en segundos.", FontFactory.GetFont("ARIAL", 11));
                        Paragraph descripcion = new Paragraph(ChunkDescripcion);
                        descripcion.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(descripcion);
                        PdfPTable TablaTReaccion = new PdfPTable(4);
                        foreach (Series item in tiempoReaccion)
                        {
                            SumaMediaFinal = SumaMediaFinal + item.Media;

                        }
                        TablaTReaccion.AddCell("Valor");
                        TablaTReaccion.AddCell("Tiempo de Reacción");
                        TablaTReaccion.AddCell("Número de terapía");
                        TablaTReaccion.AddCell("Fecha");
                        TablaTReaccion.AddCell("Primero");
                        TablaTReaccion.AddCell((tiempoReaccion.First().Media).ToString());
                        TablaTReaccion.AddCell((tiempoReaccion.First().Terapia).ToString());
                        TablaTReaccion.AddCell((tiempoReaccion.First().Fecha).ToString());
                        TablaTReaccion.AddCell("Último");
                        TablaTReaccion.AddCell((tiempoReaccion.Last().Media).ToString());
                        TablaTReaccion.AddCell((tiempoReaccion.Last().Terapia).ToString());
                        TablaTReaccion.AddCell((tiempoReaccion.Last().Fecha).ToString());
                        tiempoReaccion.Sort((x, y) => x.Media.CompareTo(y.Media));
                        TablaTReaccion.AddCell("Máximo");
                        TablaTReaccion.AddCell((tiempoReaccion.Max(x => x.Media)).ToString());
                        TablaTReaccion.AddCell((tiempoReaccion.Last().Terapia).ToString());
                        TablaTReaccion.AddCell((tiempoReaccion.Last().Fecha).ToString());
                        TablaTReaccion.AddCell("Mínimo");
                        TablaTReaccion.AddCell((tiempoReaccion.Min(x => x.Media)).ToString());
                        TablaTReaccion.AddCell((tiempoReaccion.First().Terapia).ToString());
                        TablaTReaccion.AddCell((tiempoReaccion.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaTReaccion);
                        MediaFinal = SumaMediaFinal / tiempoReaccion.Count();
                        Chunk MediaChunk = new Chunk(" Media del tiempo de reacción: " + MediaFinal, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        Paragraph ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);
                        iTextSharp.text.Image Imagen = iTextSharp.text.Image.GetInstance(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                        Imagen.Alignment = Element.ALIGN_CENTER;
                        Imagen.ScalePercent((500 / Imagen.Width) * 100);
                        Informe.Add(Imagen);
                        System.IO.File.Delete(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                    }
                }
                else
                {
                    MessageBox.Show("No hay suficientes datos para gráficar el tiempo de reacción");
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("Error debido a: " + ex.Message
                   + "\r\nError debido a: " + ex.Source
                   + "\r\nError debido a: " + ex.StackTrace
                   + "\r\nError debido a: " + ex.TargetSite);
            }
        }
        /// <summary>
        /// Es la métrica de Número de temblores, gráfica tanto en la interfaz como en el PDF, el valor es el número de veces que ha estado parado
        /// </summary>
        /// <param name="GenerarGrafico">Determina si esta métrica se incluye en el PDF</param>
        /// <param name="Informe">Es el PDF que generamos con las métricas</param>
        /// <param name="ValorTipoTerapia">Indica que tipo de terapía es la seleccionada</param>
        /// <param name="cbPaciente">ComboBox en el que seleccionamos el id del paciente</param>
        /// <param name="CbRangoTerapiaSuperior">ComboBox en el que seleccinamos la ultima terápia a representar</param>
        /// <param name="cbRangoTerapiaInferior">ComboBox en el que seleccinamos la primera terápia a representar</param>
        /// <param name="GrafTrayectoria">Es el Chart donde vamos a graficar la métrica </param>
        /// <param name="bd">Es nuestra base de datos</param>
        /// <param name="Ruta">Ruta de almacenamiento del PDF y temporalmente, de las imagenes que se incluyen en él</param>
        public static void graficaNumeroDeTemblores(bool GenerarGrafico, Document Informe, int ValorTipoTerapia, ComboBox cbPaciente, ComboBox CbRangoTerapiaSuperior, ComboBox cbRangoTerapiaInferior, Chart GrafTrayectoria, bbddDataContext bd, string Ruta)
        {
            //Es la métrica de Número de temblores, gráfica tanto en la interfaz como en el pdf, el valor es el número de veces que ha estado parado
            try
            {
                //Obtenemos los valores que nos interesan de los ComboBox
                string idPacienteSeleccionado = cbPaciente.SelectedValue.ToString();
                string rangoSuperior = CbRangoTerapiaSuperior.SelectedValue.ToString();
                string rangoInferior = cbRangoTerapiaInferior.SelectedValue.ToString();
                int tipoTerapia = ValorTipoTerapia;
                //Realizamos la consulta de los datos que nos interesan
                var resultado = (from Terapia in bd.TerapiaBM
                                 join m in bd.Muestra on Terapia.IdTerapia equals m.IdTerapia
                                 where Terapia.IdPaciente == int.Parse(idPacienteSeleccionado) && Terapia.IdTerapia > int.Parse(rangoInferior) && Terapia.IdTerapia < int.Parse(rangoSuperior) && Terapia.TipoTerapia == tipoTerapia
                                 orderby m.IdMuestra, Terapia.IdTerapia
                                 select new { Terapia.IdTerapia, m.IdMuestra, m.PosicionX, m.PosicionY, m.PuntoDeseadoX, m.PuntoDeseadoY, Terapia.IdPaciente, Terapia.Fecha }).Distinct().ToList();
                resultado = resultado.OrderBy(o => o.IdTerapia).ToList();
                List<Series> numeroDeTemblores = new List<Series>();//Lista en la que almacenamos los datos de interes y los que vamos a gráficar
                List<float> puntoX = new List<float>();
                List<float> puntoY = new List<float>();
                List<float> puntoXf = new List<float>();
                List<float> puntoYf = new List<float>();
                int contador = resultado.First().IdTerapia;// Contador nos indica en la terapia que nos encontramos
                string datosGrafica;
                string FechaTerapia = "";
                float px = 0;
                float py = 0;
                //Valores maximos yu minimos para realizar la calibración
                //Para calibrar la posición X 
                float pxo = (float)resultado.Min(x => x.PosicionX);
                float escaladoX = 1;
                float minPdx = (float)resultado.Min(x => (float)x.PuntoDeseadoX);
                float maxPdx = (float)resultado.Max(x => (float)x.PuntoDeseadoX);
                float pCalibradoX = 0;
                //Para calibrar la posición Y
                float pyo = (float)resultado.Min(x => x.PosicionY);
                float maxPdy = (float)resultado.Max(x => (float)x.PuntoDeseadoY);
                float minPdy = (float)resultado.Min(x => (float)x.PuntoDeseadoY);
                float escaladoY = 1;
                float pCalibradoY = 0;
                float pxf = 0;
                float pyf = 0;
                int longitud = 0;//Determina la cantidad de datos validos(tratados) en una terapia
                List<float> posRobot = new List<float>();
                List<float> posObj = new List<float>();
                int sumaParoRobot = 0;
                int sumaParoObj = 0;
                int comparacion = 0;
                int k = 0;

                foreach (var item in resultado)
                {

                    if (k > 4)//Eliminamos los 5 primeros valores por un error de calibración
                    {
                        if (contador == item.IdTerapia)
                        {
                            FechaTerapia = item.Fecha.ToString();
                            px = float.Parse((item.PosicionX).ToString());
                            py = float.Parse((item.PosicionY).ToString());
                            if (tipoTerapia == 2)
                            {
                                pCalibradoX = pxo - escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - maxPdx);
                                pCalibradoY = pyo - escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - maxPdy);
                            }
                            else
                            {
                                pCalibradoX = pxo + escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - minPdx);
                                pCalibradoY = pyo + escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - minPdy);
                            }
                            pxf = pCalibradoX;
                            pyf = pCalibradoY;
                            puntoX.Add(px);
                            puntoY.Add(py);
                            puntoYf.Add(pyf);
                            puntoXf.Add(pxf);
                            longitud++;

                        }
                        else// se ha producido un cambio de terapia, luego tratamos los datos de la terapia anterior
                        {
                            if (longitud > 500) // Cuando en una terapia no tenemos suficientes valores no les tratamos y pasamos a la siguiente.
                            {
                                for (int i = 0; i < longitud - 1; i++)
                                {
                                    posRobot.Add((float)Math.Sqrt(Math.Pow((puntoX[i + 1] - puntoX[i]), 2) + Math.Pow((puntoY[i + 1] - puntoY[i]), 2)));
                                    posObj.Add((float)Math.Sqrt(Math.Pow((puntoXf[i + 1] - puntoXf[i]), 2) + Math.Pow((puntoYf[i + 1] - puntoYf[i]), 2)));
                                }
                                for (int i = 0; i < longitud - 3; i++)
                                {
                                    if ((posRobot[i + 1] == 0) && (posRobot[i] != 0))
                                    {
                                        sumaParoRobot++;
                                    }
                                    if ((posObj[i + 1] == 0) && (posObj[i] != 0))
                                    {
                                        sumaParoObj++;
                                    }
                                }
                                comparacion = sumaParoRobot - sumaParoObj;

                                numeroDeTemblores.Add(
                                    new Series
                                    {
                                        ObjParado = sumaParoObj,
                                        RobParado = sumaParoRobot,
                                        Compara = comparacion,
                                        Fecha = FechaTerapia,
                                        Terapia = contador
                                    }
                                    );
                                sumaParoRobot = 0;
                                sumaParoObj = 0;
                                comparacion = 0;
                                longitud = 0;
                                puntoXf.Clear();
                                puntoX.Clear();
                                puntoY.Clear();
                                puntoYf.Clear();
                                posObj.Clear();
                                posRobot.Clear();
                                contador= item.IdTerapia;// Para buscar la siguiente terapia.
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                            }

                            else // Cuando en una terapia no tenemos suficientes valores no les tratamos y pasamos a la siguiente.
                            {
                                sumaParoRobot = 0;
                                sumaParoObj = 0;
                                comparacion = 0;
                                longitud = 0;
                                puntoXf.Clear();
                                puntoX.Clear();
                                puntoY.Clear();
                                puntoYf.Clear();
                                posObj.Clear();
                                posRobot.Clear();
                                contador= item.IdTerapia;
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                            }
                        }
                    }
                    k++;
                }
                numeroDeTemblores = numeroDeTemblores.OrderBy(o => o.Terapia).ToList();
                if (numeroDeTemblores.Any())
                {
                    //Graficamos
                    GrafTrayectoria.ChartAreas.Clear();
                    GrafTrayectoria.ChartAreas.Add("Número de temblores");
                    GrafTrayectoria.Series.Clear();
                    GrafTrayectoria.DataSource = null;
                    GrafTrayectoria.DataSource = numeroDeTemblores;
                    GrafTrayectoria.Series.Add("Veces que el paciente está parado");
                    GrafTrayectoria.Series["Veces que el paciente está parado"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Veces que el paciente está parado"].YValueMembers = "RobParado";
                    GrafTrayectoria.Series["Veces que el paciente está parado"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Veces que el paciente está parado"].BorderWidth = 3;
                    GrafTrayectoria.Series.Add("Veces que el objetivo está parado");
                    GrafTrayectoria.Series["Veces que el objetivo está parado"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Veces que el objetivo está parado"].YValueMembers = "ObjParado";
                    GrafTrayectoria.Series["Veces que el objetivo está parado"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Veces que el objetivo está parado"].BorderWidth = 3;
                    GrafTrayectoria.Series.Add("Veces que el paciente está parado respecto al objetivo");
                    GrafTrayectoria.Series["Veces que el paciente está parado respecto al objetivo"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Veces que el paciente está parado respecto al objetivo"].YValueMembers = "Compara";
                    GrafTrayectoria.Series["Veces que el paciente está parado respecto al objetivo"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Veces que el paciente está parado respecto al objetivo"].BorderWidth = 3;
                    GrafTrayectoria.ChartAreas["Número de temblores"].AxisX.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["Número de temblores"].AxisX.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["Número de temblores"].AxisY.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;//AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["Número de temblores"].AxisY.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["Número de temblores"].CursorX.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["Número de temblores"].CursorY.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["Número de temblores"].Visible = true;
                    GrafTrayectoria.ChartAreas["Número de temblores"].AxisX.Title = "Terapias";
                    GrafTrayectoria.ChartAreas["Número de temblores"].AxisY.Title = "Número de veces";
                    GrafTrayectoria.ChartAreas["Número de temblores"].AxisX.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.ChartAreas["Número de temblores"].AxisY.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.Titles.Clear();
                    GrafTrayectoria.Titles.Add("Número de temblores");
                    datosGrafica = "Paciente = " + idPacienteSeleccionado + " Tipo de terapia = " + tipoTerapia + " Rango = Desde " + numeroDeTemblores.First().Terapia + " hasta " + contador;
                    GrafTrayectoria.Titles.Add(datosGrafica);
                    if (GenerarGrafico)
                    {
                        //Generamos el informe con una breve descripción, tablas de información y la gráfica
                        float SumaMediaFinal = 0;
                        float MediaFinal = 0;
                        string NombreImagen = "Velocidad_Paciente_";
                        GrafTrayectoria.SaveImage(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png", System.Drawing.Imaging.ImageFormat.Png);
                        Chunk ChunkDescripcion = new Chunk("Se observa cuántas veces ha estado parado el robot cuando era manejado por el fisioterapeuta o cuántas veces el ratón en la pantalla ha estado en una posición fija, y cuántas veces ha estado parado el paciente, así como la comparación de la mismas.\n El índice es el número de veces que el robot está parado.", FontFactory.GetFont("ARIAL", 11));
                        Paragraph descripcion = new Paragraph(ChunkDescripcion);
                        descripcion.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(descripcion);
                        PdfPTable TablaTemblores = new PdfPTable(4);
                        foreach (Series item in numeroDeTemblores)
                        {
                            SumaMediaFinal = SumaMediaFinal + item.Compara;

                        }
                        TablaTemblores.AddCell("Valor");
                        TablaTemblores.AddCell("Relación Robot/Paciente");
                        TablaTemblores.AddCell("Número de terapía");
                        TablaTemblores.AddCell("Fecha");
                        TablaTemblores.AddCell("Primero");
                        TablaTemblores.AddCell((numeroDeTemblores.First().Compara).ToString());
                        TablaTemblores.AddCell((numeroDeTemblores.First().Terapia).ToString());
                        TablaTemblores.AddCell((numeroDeTemblores.First().Fecha).ToString());
                        TablaTemblores.AddCell("Último");
                        TablaTemblores.AddCell((numeroDeTemblores.Last().Compara).ToString());
                        TablaTemblores.AddCell((numeroDeTemblores.Last().Terapia).ToString());
                        TablaTemblores.AddCell((numeroDeTemblores.Last().Fecha).ToString());
                        numeroDeTemblores.Sort((x, y) => x.Compara.CompareTo(y.Compara));
                        TablaTemblores.AddCell("Máximo");
                        TablaTemblores.AddCell((numeroDeTemblores.Max(x => x.Compara)).ToString());
                        TablaTemblores.AddCell((numeroDeTemblores.Last().Terapia).ToString());
                        TablaTemblores.AddCell((numeroDeTemblores.Last().Fecha).ToString());
                        TablaTemblores.AddCell("Mínimo");
                        TablaTemblores.AddCell((numeroDeTemblores.Min(x => x.Compara)).ToString());
                        TablaTemblores.AddCell((numeroDeTemblores.First().Terapia).ToString());
                        TablaTemblores.AddCell((numeroDeTemblores.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaTemblores);
                        MediaFinal = SumaMediaFinal / numeroDeTemblores.Count();
                        Chunk MediaChunk = new Chunk(" Media del Número de temblores: " + MediaFinal, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        Paragraph ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);
                        iTextSharp.text.Image Imagen = iTextSharp.text.Image.GetInstance(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                        Imagen.Alignment = Element.ALIGN_CENTER;
                        Imagen.ScalePercent((500 / Imagen.Width) * 100);
                        Informe.Add(Imagen);
                        System.IO.File.Delete(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                    }
                }
                else
                {
                    MessageBox.Show("No hay suficientes datos para gráficar el número de temblores");
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("Error debido a: " + ex.Message
                   + "\r\nError debido a: " + ex.Source
                   + "\r\nError debido a: " + ex.StackTrace
                   + "\r\nError debido a: " + ex.TargetSite);
            }

        }
        /// <summary>
        /// Es la métrica de Simetría direccional x e y, gráfica tanto en la interfaz como en el PDF, el valor es la simetría direccional
        /// </summary>
        /// <param name="GenerarGrafico">Determina si esta métrica se incluye en el PDF</param>
        /// <param name="Informe">Es el PDF que generamos con las métricas</param>
        /// <param name="ValorTipoTerapia">Indica que tipo de terapía es la seleccionada</param>
        /// <param name="cbPaciente">ComboBox en el que seleccionamos el id del paciente</param>
        /// <param name="CbRangoTerapiaSuperior">ComboBox en el que seleccinamos la ultima terápia a representar</param>
        /// <param name="cbRangoTerapiaInferior">ComboBox en el que seleccinamos la primera terápia a representar</param>
        /// <param name="GrafTrayectoria">Es el Chart donde vamos a graficar la métrica </param>
        /// <param name="bd">Es nuestra base de datos</param>
        /// <param name="Ruta">Ruta de almacenamiento del PDF y temporalmente, de las imagenes que se incluyen en él</param>
        public static void graficaDireccional(bool GenerarGrafico, Document Informe, int ValorTipoTerapia, ComboBox cbPaciente, ComboBox CbRangoTerapiaSuperior, ComboBox cbRangoTerapiaInferior, Chart GrafTrayectoria, bbddDataContext bd, string Ruta)
        {            
            try
            {
                //Obtenemos los valores que nos interesan de los ComboBox
                string idPacienteSeleccionado = cbPaciente.SelectedValue.ToString();
                string rangoSuperior = CbRangoTerapiaSuperior.SelectedValue.ToString();
                string rangoInferior = cbRangoTerapiaInferior.SelectedValue.ToString();
                int tipoTerapia = ValorTipoTerapia;
                //Realizamos la consulta de los datos que nos interesan
                var resultado = (from Terapia in bd.TerapiaBM
                                 join m in bd.Muestra on Terapia.IdTerapia equals m.IdTerapia
                                 where Terapia.IdPaciente == int.Parse(idPacienteSeleccionado) && Terapia.IdTerapia > int.Parse(rangoInferior) && Terapia.IdTerapia < int.Parse(rangoSuperior) && Terapia.TipoTerapia == tipoTerapia
                                 orderby m.IdMuestra, Terapia.IdTerapia
                                 select new { Terapia.IdTerapia, m.IdMuestra, m.PosicionX, m.PosicionY, m.PuntoDeseadoX, m.PuntoDeseadoY, Terapia.IdPaciente, Terapia.Fecha }).Distinct().ToList();
                resultado = resultado.OrderBy(o => o.IdTerapia).ToList();
                List<Series> listaDireccional = new List<Series>();//Lista en la que almacenamos los datos de interes y los que vamos a gráficar
                List<float> puntoX = new List<float>();
                List<float> puntoY = new List<float>();
                List<float> puntoXf = new List<float>();
                List<float> puntoYf = new List<float>();
                int contador = resultado.First().IdTerapia;// Contador nos indica en la terapia que nos encontramos
                string datosGrafica;
                string fechaTerapia = "";
                float px = 0;
                float py = 0;
                //Valores maximos yu minimos para realizar la calibración
                //Para calibrar la posición X 
                float pxo = (float)resultado.Min(x => x.PosicionX);
                float escaladoX = 1;
                float minPdx = (float)resultado.Min(x => (float)x.PuntoDeseadoX);
                float maxPdx = (float)resultado.Max(x => (float)x.PuntoDeseadoX);
                float pCalibradoX = 0;
                //Para calibrar la posición Y
                float pyo = (float)resultado.Min(x => x.PosicionY);
                float maxPdy = (float)resultado.Max(x => (float)x.PuntoDeseadoY);
                float MinPdy = (float)resultado.Min(x => (float)x.PuntoDeseadoY);
                float escaladoY = 1;
                float pCalibradoY = 0;
                float pxf = 0;
                float pyf = 0;
                int longitud = 0;//Determina la cantidad de datos validos(tratados) en una terapia
                double dpxt = 0;
                double dpyt = 0;
                int sumaXX = 0;
                int sumaYY = 0;
                int k = 0;

                foreach (var item in resultado)
                {

                    if (k > 4)//Eliminamos los 5 primeros valores por un error de calibración
                    {
                        if (contador == item.IdTerapia)
                        {
                            fechaTerapia = item.Fecha.ToString();
                            px = float.Parse((item.PosicionX).ToString());
                            py = float.Parse((item.PosicionY).ToString());
                            if (tipoTerapia == 2)
                            {
                                pCalibradoX = pxo - escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - maxPdx);
                                pCalibradoY = pyo - escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - maxPdy);
                            }
                            else
                            {
                                pCalibradoX = pxo + escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - minPdx);
                                pCalibradoY = pyo + escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - MinPdy);
                            }
                            pxf = pCalibradoX;
                            pyf = pCalibradoY;
                            puntoX.Add(px);
                            puntoY.Add(py);
                            puntoYf.Add(pyf);
                            puntoXf.Add(pxf);
                            longitud++;

                        }
                        else// se ha producido un cambio de terapia, luego tratamos los datos de la terapia anterior
                        {
                            if (longitud > 2500) // Cuando en una terapia no tenemos suficientes valores no les tratamos y pasamos a la siguiente.
                            {
                                for (int i = 0; i < longitud - 1; i++)
                                {
                                    dpxt = (puntoX[i + 1] - puntoX[i]) * (puntoXf[i + 1] - puntoXf[i]);
                                    dpyt = (puntoY[i + 1] - puntoY[i]) * (puntoYf[i + 1] - puntoYf[i]);
                                    if (dpxt >= 0)
                                    {
                                        sumaXX++;
                                    }
                                    if (dpyt >= 0)
                                    {
                                        sumaYY++;
                                    }
                                }

                                listaDireccional.Add(
                                    new Series
                                    {                                     
                                        MediaY = sumaYY * 100 / longitud,
                                        MediaX = sumaXX * 100 / longitud,
                                        Fecha = fechaTerapia,
                                        Terapia = contador
                                    }
                                    );
                                sumaXX = 0;
                                sumaYY = 0;
                                longitud = 0;
                                puntoXf.Clear();
                                puntoX.Clear();
                                puntoY.Clear();
                                puntoYf.Clear();
                                contador=item.IdTerapia;// Para buscar la siguiente terapia.
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                            }

                            else // Cuando en una terapia no tenemos suficientes valores no les tratamos y pasamos a la siguiente.
                            {
                                sumaXX = 0;
                                sumaYY = 0;
                                longitud = 0;
                                puntoXf.Clear();
                                puntoX.Clear();
                                puntoY.Clear();
                                puntoYf.Clear();
                                contador=item.IdTerapia;
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                            }
                        }
                    }
                    k++;
                }
                listaDireccional = listaDireccional.OrderBy(o => o.Terapia).ToList();
                if (listaDireccional.Any())
                {
                    //Graficamos
                    GrafTrayectoria.ChartAreas.Clear();
                    GrafTrayectoria.ChartAreas.Add("Simetría Direccional");
                    GrafTrayectoria.Series.Clear();
                    GrafTrayectoria.DataSource = null;
                    GrafTrayectoria.DataSource = listaDireccional;
                    GrafTrayectoria.Series.Add("Simetría direccional x");
                    GrafTrayectoria.Series["Simetría direccional x"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Simetría direccional x"].YValueMembers = "MediaX";
                    GrafTrayectoria.Series["Simetría direccional x"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Simetría direccional x"].BorderWidth = 3;
                    GrafTrayectoria.Series.Add("Simetría direccional y");
                    GrafTrayectoria.Series["Simetría direccional y"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Simetría direccional y"].YValueMembers = "MediaY";
                    GrafTrayectoria.Series["Simetría direccional y"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Simetría direccional y"].BorderWidth = 3;
                    GrafTrayectoria.ChartAreas["Simetría Direccional"].AxisX.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["Simetría Direccional"].AxisX.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["Simetría Direccional"].AxisY.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;//AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["Simetría Direccional"].AxisY.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["Simetría Direccional"].CursorX.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["Simetría Direccional"].CursorY.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["Simetría Direccional"].Visible = true;
                    GrafTrayectoria.ChartAreas["Simetría Direccional"].AxisX.Title = "Terapias";
                    GrafTrayectoria.ChartAreas["Simetría Direccional"].AxisY.Title = "Porcentaje de simetría(%)";
                    GrafTrayectoria.ChartAreas["Simetría Direccional"].AxisX.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.ChartAreas["Simetría Direccional"].AxisY.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.Titles.Clear();
                    GrafTrayectoria.Titles.Add("Simetría direccional en x y en y");
                    datosGrafica = "Paciente = " + idPacienteSeleccionado + " Tipo de terapia = " + tipoTerapia + " Rango = Desde " + listaDireccional.First().Terapia + " hasta " + contador;
                    GrafTrayectoria.Titles.Add(datosGrafica);
                    if (GenerarGrafico)
                    {
                        //Generamos el informe con una breve descripción, tablas de información y la gráfica
                        float SumaDireccionalX = 0;
                        float SumaDireccionalY = 0;
                        float TotalDireccionalX = 0;
                        float TotalDireccionalY = 0;
                        string NombreImagen = "Simetría_Direccional_Paciente_";
                        GrafTrayectoria.SaveImage(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png", System.Drawing.Imaging.ImageFormat.Png);
                        Chunk ChunkDescripcion = new Chunk("En el análisis estadístico de una serie temporal y en el procesamiento de la señal, la simetría direccional es una medida estadística de rendimiento de un modelo para predecir el cambio, positivo o negativo, de una serie temporal de un período de tiempo al siguiente. \nEl índice de la simetría direccionales es el porcentaje de simetría direccional(%).", FontFactory.GetFont("ARIAL", 11));
                        Paragraph descripcion = new Paragraph(ChunkDescripcion);
                        descripcion.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(descripcion);
                        PdfPTable TablaDireccionalX = new PdfPTable(4);
                        PdfPTable TablaDireccionalY = new PdfPTable(4);
                        foreach (Series item in listaDireccional)
                        {
                            SumaDireccionalX = SumaDireccionalX + item.MediaX;
                            SumaDireccionalY = SumaDireccionalY + item.MediaY;

                        }
                        TablaDireccionalX.AddCell("Valor");
                        TablaDireccionalX.AddCell("Simetría direccional X");
                        TablaDireccionalX.AddCell("Terapia");
                        TablaDireccionalX.AddCell("Fecha");
                        TablaDireccionalX.AddCell("Primero");
                        TablaDireccionalX.AddCell((listaDireccional.First().MediaX).ToString());
                        TablaDireccionalX.AddCell((listaDireccional.First().Terapia).ToString());
                        TablaDireccionalX.AddCell((listaDireccional.First().Fecha).ToString());
                        TablaDireccionalX.AddCell("Último");
                        TablaDireccionalX.AddCell((listaDireccional.Last().MediaX).ToString());
                        TablaDireccionalX.AddCell((listaDireccional.Last().Terapia).ToString());
                        TablaDireccionalX.AddCell((listaDireccional.Last().Fecha).ToString());
                        listaDireccional.Sort((x, y) => x.MediaX.CompareTo(y.MediaX));
                        TablaDireccionalX.AddCell("Máximo");
                        TablaDireccionalX.AddCell((listaDireccional.Max(x => x.MediaX)).ToString());
                        TablaDireccionalX.AddCell((listaDireccional.Last().Terapia).ToString());
                        TablaDireccionalX.AddCell((listaDireccional.Last().Fecha).ToString());
                        TablaDireccionalX.AddCell("Mínimo");
                        TablaDireccionalX.AddCell((listaDireccional.Min(x => x.MediaX)).ToString());
                        TablaDireccionalX.AddCell((listaDireccional.First().Terapia).ToString());
                        TablaDireccionalX.AddCell((listaDireccional.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaDireccionalX);
                        TotalDireccionalX = SumaDireccionalX / listaDireccional.Count();
                        Chunk MediaChunk = new Chunk(" Media de la simetría direccional X: " + TotalDireccionalX, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        Paragraph ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);

                        TablaDireccionalY.AddCell("Valor");
                        TablaDireccionalY.AddCell("Simetría direccional Y");
                        TablaDireccionalY.AddCell("Terapia");
                        TablaDireccionalY.AddCell("Fecha");
                        TablaDireccionalY.AddCell("Primero");
                        TablaDireccionalY.AddCell((listaDireccional.First().MediaY).ToString());
                        TablaDireccionalY.AddCell((listaDireccional.First().Terapia).ToString());
                        TablaDireccionalY.AddCell((listaDireccional.First().Fecha).ToString());
                        TablaDireccionalY.AddCell("Último");
                        TablaDireccionalY.AddCell((listaDireccional.Last().MediaY).ToString());
                        TablaDireccionalY.AddCell((listaDireccional.Last().Terapia).ToString());
                        TablaDireccionalY.AddCell((listaDireccional.Last().Fecha).ToString());
                        listaDireccional.Sort((x, y) => x.MediaY.CompareTo(y.MediaY));
                        TablaDireccionalY.AddCell("Máximo");
                        TablaDireccionalY.AddCell((listaDireccional.Max(x => x.MediaY)).ToString());
                        TablaDireccionalY.AddCell((listaDireccional.Last().Terapia).ToString());
                        TablaDireccionalY.AddCell((listaDireccional.Last().Fecha).ToString());
                        TablaDireccionalY.AddCell("Mínimo");
                        TablaDireccionalY.AddCell((listaDireccional.Min(x => x.MediaY)).ToString());
                        TablaDireccionalY.AddCell((listaDireccional.First().Terapia).ToString());
                        TablaDireccionalY.AddCell((listaDireccional.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaDireccionalY);
                        TotalDireccionalY = SumaDireccionalY / listaDireccional.Count();
                        MediaChunk = new Chunk(" Media de la simetría direccional Y: " + TotalDireccionalY, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);
                        iTextSharp.text.Image Imagen = iTextSharp.text.Image.GetInstance(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                        Imagen.Alignment = Element.ALIGN_CENTER;
                        Imagen.ScalePercent((500 / Imagen.Width) * 100);
                        Informe.Add(Imagen);
                        System.IO.File.Delete(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                    }
                }
                else
                {
                    MessageBox.Show("No hay suficientes datos para gráficar la simetría direccional x e y");
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("Error debido a: " + ex.Message
                   + "\r\nError debido a: " + ex.Source
                   + "\r\nError debido a: " + ex.StackTrace
                   + "\r\nError debido a: " + ex.TargetSite);
            }

        }
        /// <summary>
        /// Es la métrica de simetría de velocidad y ángulo, gráfica tanto en la interfaz como en el PDF, el valor es la simetría de la magnitud de la velocidad y la simetría del ángulo
        /// </summary>
        /// <param name="GenerarGrafico">Determina si esta métrica se incluye en el PDF</param>
        /// <param name="Informe">Es el PDF que generamos con las métricas</param>
        /// <param name="ValorTipoTerapia">Indica que tipo de terapía es la seleccionada</param>
        /// <param name="cbPaciente">ComboBox en el que seleccionamos el id del paciente</param>
        /// <param name="CbRangoTerapiaSuperior">ComboBox en el que seleccinamos la ultima terápia a representar</param>
        /// <param name="cbRangoTerapiaInferior">ComboBox en el que seleccinamos la primera terápia a representar</param>
        /// <param name="GrafTrayectoria">Es el Chart donde vamos a graficar la métrica</param>
        /// <param name="bd">Es nuestra base de datos</param>
        /// <param name="Ruta">Ruta de almacenamiento del PDF y temporalmente, de las imagenes que se incluyen en él</param>
        public static void graficaSimetriaVA(bool GenerarGrafico, Document Informe, int ValorTipoTerapia, ComboBox cbPaciente, ComboBox CbRangoTerapiaSuperior, ComboBox cbRangoTerapiaInferior, Chart GrafTrayectoria, bbddDataContext bd, string Ruta)
        {
            //Es la métrica de simetría de velocidad y ángulo, gráfica tanto en la interfaz como en el pdf, el valor es la simetría de la magnitud de la velocidad y la simetría del ángulo
            try
            {
                //Obtenemos los valores que nos interesan de los ComboBox
                string idPacienteSeleccionado = cbPaciente.SelectedValue.ToString();
                string rangoSuperior = CbRangoTerapiaSuperior.SelectedValue.ToString();
                string rangoInferior = cbRangoTerapiaInferior.SelectedValue.ToString();
                int tipoTerapia = ValorTipoTerapia;
                //Realizamos la consulta de los datos que nos interesan
                var resultado = (from Terapia in bd.TerapiaBM
                                 join m in bd.Muestra on Terapia.IdTerapia equals m.IdTerapia
                                 where Terapia.IdPaciente == int.Parse(idPacienteSeleccionado) && Terapia.IdTerapia > int.Parse(rangoInferior) && Terapia.IdTerapia < int.Parse(rangoSuperior) && Terapia.TipoTerapia == tipoTerapia
                                 orderby m.IdMuestra, Terapia.IdTerapia
                                 select new { Terapia.IdTerapia, m.IdMuestra, m.PosicionX, m.PosicionY, m.PuntoDeseadoX, m.PuntoDeseadoY, Terapia.IdPaciente, m.Tiempo, Terapia.Fecha }).Distinct().ToList();
                resultado = resultado.OrderBy(o => o.IdTerapia).ToList();
                List<Series> simetria = new List<Series>();//Lista en la que almacenamos los datos de interes y los que vamos a gráficar
                List<float> puntoX = new List<float>();
                List<float> puntoY = new List<float>();
                List<float> puntoXf = new List<float>();
                List<float> puntoYf = new List<float>();
                List<float> listaVxObj = new List<float>();
                List<float> listaVyObj = new List<float>();
                List<float> listaVyRobot = new List<float>();
                List<float> listaVxRobot = new List<float>();
                List<float> listaTiempo = new List<float>();
                List<float> listaAnguloRobot = new List<float>();
                List<float> listaAnguloObj = new List<float>();
                List<float> listaMagnitudRobot = new List<float>();
                List<float> listaMagnitudObjeto = new List<float>();
                int contador = resultado.First().IdTerapia;// Contador nos indica en la terapia que nos encontramos
                string datosGrafica;
                string fechaTerapia = "";
                string[] TiempoSeparado;
                double diffT = 0;
                //Valores maximos yu minimos para realizar la calibración
                //Para calibrar la posición X 
                float Pxo = (float)resultado.Min(x => x.PosicionX);
                float escaladoX = 1;
                float minPdx = (float)resultado.Min(x => (float)x.PuntoDeseadoX);
                float maxPdx = (float)resultado.Max(x => (float)x.PuntoDeseadoX);
                float PcalibradoX = 0;
                //Para calibrar la posición Y
                float pyo = (float)resultado.Min(x => x.PosicionY);
                float maxPdy = (float)resultado.Max(x => (float)x.PuntoDeseadoY);
                float minPdy = (float)resultado.Min(x => (float)x.PuntoDeseadoY);
                float escaladoY = 1;
                float pCalibradoY = 0;
                double s1 = 0;
                double s2 = 0;
                double s3 = 0;
                double tiempo = 0;
                int longitud = 0;//Determina la cantidad de datos validos(tratados) en una terapia
                float vyObj = 0;
                float vxObj = 0;
                float vxRobot = 0;
                float vyRobot = 0;
                float magObj = 0;
                float magRobot = 0;
                float anguloVelRobot = 0;
                float anguloVelObj = 0;
                int sumaVx = 0;
                int sumaVy = 0;
                int sumaMagnitud = 0;
                int sumaAngulo = 0;
                int k = 0;

                foreach (var item in resultado)
                {

                    if (k > 4)//Eliminamos los 5 primeros valores por un error de calibración
                    {
                        if (contador == item.IdTerapia)
                        {
                            fechaTerapia = item.Fecha.ToString();
                            TiempoSeparado = (item.Tiempo).Split(':');
                            s1 = double.Parse(TiempoSeparado[0]) * 3600;
                            s2 = double.Parse(TiempoSeparado[1]) * 60;
                            s3 = double.Parse(TiempoSeparado[2]);
                            tiempo = s1 + s2 + s3 / 10000000;
                            listaTiempo.Add((float)tiempo);
                            puntoX.Add(float.Parse((item.PosicionX).ToString()));
                            puntoY.Add(float.Parse((item.PosicionY).ToString()));
                            if (tipoTerapia == 2)
                            {
                                PcalibradoX = Pxo - escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - maxPdx);
                                pCalibradoY = pyo - escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - maxPdy);
                            }
                            else
                            {
                                PcalibradoX = Pxo + escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - minPdx);
                                pCalibradoY = pyo + escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - minPdy);
                            }
                            puntoYf.Add(PcalibradoX);
                            puntoXf.Add(pCalibradoY);
                            longitud++;

                        }
                        else// se ha producido un cambio de terapia, luego tratamos los datos de la terapia anterior
                        {
                            if (longitud > 500) // Cuando en una terapia no tenemos suficientes valores no les tratamos y pasamos a la siguiente.
                            {
                                for (int i = 0; i < longitud - 1; i++)
                                {
                                    diffT = (listaTiempo[i + 1] - listaTiempo[i]);
                                    vxRobot = (puntoX[i + 1] - puntoX[i]) / ((listaTiempo[i + 1] - listaTiempo[i]) * 1000);
                                    vyRobot = (puntoY[i + 1] - puntoY[i]) / ((listaTiempo[i + 1] - listaTiempo[i]) * 1000);
                                    vxObj = (puntoXf[i + 1] - puntoXf[i]) / ((listaTiempo[i + 1] - listaTiempo[i]) * 1000);
                                    vyObj = (puntoYf[i + 1] - puntoYf[i]) / ((listaTiempo[i + 1] - listaTiempo[i]) * 1000);
                                    magRobot = (float)Math.Sqrt(Math.Pow(vxRobot, 2) + Math.Pow(vyRobot, 2));
                                    magObj = (float)Math.Sqrt(Math.Pow((vxObj), 2) + Math.Pow(vyObj, 2));
                                    anguloVelRobot = (float)Math.Asin(vyRobot / magRobot);
                                    anguloVelObj = (float)Math.Asin(vyObj / magObj);
                                    listaVxObj.Add(vxObj);
                                    listaVxRobot.Add(vxRobot);
                                    listaVyObj.Add(vyObj);
                                    listaVyRobot.Add(vyRobot);
                                    listaMagnitudRobot.Add(magRobot);
                                    listaMagnitudObjeto.Add(magObj);
                                    listaAnguloRobot.Add(anguloVelRobot);
                                    listaAnguloObj.Add(anguloVelObj);
                                }
                                for (int i = 0; i < longitud - 2; i++)
                                {
                                    if ((listaVxRobot[i + 1] - listaVxRobot[i]) * (listaVxObj[i + 1] - listaVxObj[i]) >= 0)
                                    {
                                        sumaVx++;
                                    }
                                    if ((listaVyRobot[i + 1] - listaVyRobot[i]) * (listaVyObj[i + 1] - listaVyObj[i]) >= 0)
                                    {
                                        sumaVy++;
                                    }
                                    if (((listaMagnitudObjeto[i + 1] - listaMagnitudObjeto[i]) * (listaMagnitudRobot[i + 1] - listaMagnitudRobot[1])) >= 0)
                                    {
                                        sumaMagnitud++;
                                    }
                                    if (((listaAnguloObj[i + 1] - listaAnguloObj[i]) * (listaAnguloRobot[i + 1] - listaAnguloRobot[i])) >= 0)
                                    {
                                        sumaAngulo++;
                                    }
                                }
                                if (sumaAngulo * 100 / (longitud - 1) > 30 && sumaMagnitud * 100 / (longitud - 1)> 30 && sumaVy * 100 / (longitud - 1) >30 && sumaVx * 100 / (longitud - 1)>30)
                                {
                                    simetria.Add(
                                        new Series
                                        {
                                            Magnitud = sumaMagnitud * 100 / (longitud - 1),
                                            Angulo = sumaAngulo * 100 / (longitud - 1),
                                            MediaY = sumaVy * 100 / (longitud - 1),
                                            MediaX = sumaVx * 100 / (longitud - 1),
                                            Fecha = fechaTerapia,
                                            Terapia = contador
                                        }
                                        );
                                }
                                sumaAngulo = 0;
                                sumaMagnitud = 0;
                                sumaVx = 0;
                                sumaVy = 0;
                                longitud = 0;
                                puntoXf.Clear();
                                puntoX.Clear();
                                puntoY.Clear();
                                puntoYf.Clear();
                                listaAnguloObj.Clear();
                                listaAnguloRobot.Clear();
                                listaMagnitudObjeto.Clear();
                                listaMagnitudRobot.Clear();
                                listaTiempo.Clear();
                                listaVxObj.Clear();
                                listaVxRobot.Clear();
                                listaVyObj.Clear();
                                listaVyRobot.Clear();
                                contador=item.IdTerapia;// Para buscar la siguiente terapia.
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                            }

                            else // Cuando en una terapia no tenemos suficientes valores no les tratamos y pasamos a la siguiente.
                            {
                                sumaAngulo = 0;
                                sumaMagnitud = 0;
                                sumaVx = 0;
                                sumaVy = 0;
                                longitud = 0;
                                puntoXf.Clear();
                                puntoX.Clear();
                                puntoY.Clear();
                                puntoYf.Clear();
                                listaAnguloObj.Clear();
                                listaAnguloRobot.Clear();
                                listaMagnitudObjeto.Clear();
                                listaMagnitudRobot.Clear();
                                listaTiempo.Clear();
                                listaVxObj.Clear();
                                listaVxRobot.Clear();
                                listaVyObj.Clear();
                                listaVyRobot.Clear();
                                contador=item.IdTerapia;
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                            }
                        }
                    }
                    k++;
                }
                simetria = simetria.OrderBy(o => o.Terapia).ToList();
                if (simetria.Any())
                {
                    //Graficamos
                    GrafTrayectoria.ChartAreas.Clear();
                    GrafTrayectoria.ChartAreas.Add("SimetriaVA");
                    GrafTrayectoria.Series.Clear();
                    GrafTrayectoria.DataSource = null;
                    GrafTrayectoria.DataSource = simetria;
                    GrafTrayectoria.Series.Add("Simetría direccional velocidad x Robot-Objeto");
                    GrafTrayectoria.Series["Simetría direccional velocidad x Robot-Objeto"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Simetría direccional velocidad x Robot-Objeto"].YValueMembers = "MediaX";
                    GrafTrayectoria.Series["Simetría direccional velocidad x Robot-Objeto"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Simetría direccional velocidad x Robot-Objeto"].BorderWidth = 3;
                    GrafTrayectoria.Series.Add("Simetría direccional velocidad y Robot-Objeto");
                    GrafTrayectoria.Series["Simetría direccional velocidad y Robot-Objeto"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Simetría direccional velocidad y Robot-Objeto"].YValueMembers = "MediaY";
                    GrafTrayectoria.Series["Simetría direccional velocidad y Robot-Objeto"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Simetría direccional velocidad y Robot-Objeto"].BorderWidth = 3;
                    GrafTrayectoria.Series.Add("Simetría direccional magnitud velocidad Robot-Objeto");
                    GrafTrayectoria.Series["Simetría direccional magnitud velocidad Robot-Objeto"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Simetría direccional magnitud velocidad Robot-Objeto"].YValueMembers = "Magnitud";
                    GrafTrayectoria.Series["Simetría direccional magnitud velocidad Robot-Objeto"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Simetría direccional magnitud velocidad Robot-Objeto"].BorderWidth = 3;
                    GrafTrayectoria.Series.Add("Simetría direccional ángulo velocidad Robot-Objeto");
                    GrafTrayectoria.Series["Simetría direccional ángulo velocidad Robot-Objeto"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Simetría direccional ángulo velocidad Robot-Objeto"].YValueMembers = "Angulo";
                    GrafTrayectoria.Series["Simetría direccional ángulo velocidad Robot-Objeto"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Simetría direccional ángulo velocidad Robot-Objeto"].BorderWidth = 3;
                    GrafTrayectoria.ChartAreas["SimetriaVA"].AxisX.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["SimetriaVA"].AxisX.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["SimetriaVA"].AxisY.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;//AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["SimetriaVA"].AxisY.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["SimetriaVA"].CursorX.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["SimetriaVA"].CursorY.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["SimetriaVA"].Visible = true;
                    GrafTrayectoria.ChartAreas["SimetriaVA"].AxisX.Title = "Terapias";
                    GrafTrayectoria.ChartAreas["SimetriaVA"].AxisY.Title = "Porcentaje de simetría(%)";
                    GrafTrayectoria.ChartAreas["SimetriaVA"].AxisX.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.ChartAreas["SimetriaVA"].AxisY.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.Titles.Clear();
                    GrafTrayectoria.Titles.Add("Simetría de velocidad y ángulo");
                    datosGrafica = "Paciente = " + idPacienteSeleccionado + " Tipo de terapia = " + tipoTerapia + " Rango = Desde " + simetria.First().Terapia + " hasta " + contador;
                    GrafTrayectoria.Titles.Add(datosGrafica);
                    if (GenerarGrafico)
                    {
                        //Generamos el informe con una breve descripción, tablas de información y la gráfica
                        float SumaVelocidad = 0;
                        float SumaAnguloTotal = 0;
                        float TotalMagnitud = 0;
                        float TotalAngulo = 0;
                        string NombreImagen = "Simetría_Velocidad_Angulo_Paciente_";
                        GrafTrayectoria.SaveImage(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png", System.Drawing.Imaging.ImageFormat.Png);
                        Chunk ChunkDescripcion = new Chunk("Simetría direccional de la velocidad en x y en y, la magnitud de la velocidad es la semisuma al cuadrado de las velocidades x e y y el ángulo es el arcoseno de la velocidad con respecto a la magnitud y lo que se observa en la pantalla es que el porcentaje del ángulo sea el mismo del paciente y de la trayectoria objetivo. \nLos índices son porcentajes de simetría(%).", FontFactory.GetFont("ARIAL", 11));
                        Paragraph descripcion = new Paragraph(ChunkDescripcion);
                        descripcion.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(descripcion);
                        PdfPTable TablaMagnitud = new PdfPTable(4);
                        PdfPTable TablaAngulo = new PdfPTable(4);
                        foreach (Series item in simetria)
                        {
                            SumaVelocidad = SumaVelocidad + item.Magnitud;
                            SumaAnguloTotal = SumaAnguloTotal + item.Angulo;

                        }
                        TablaMagnitud.AddCell("Valor");
                        TablaMagnitud.AddCell("Magnitud de velocidad");
                        TablaMagnitud.AddCell("Terapia");
                        TablaMagnitud.AddCell("Fecha");
                        TablaMagnitud.AddCell("Primero");
                        TablaMagnitud.AddCell((simetria.First().Magnitud).ToString());
                        TablaMagnitud.AddCell((simetria.First().Terapia).ToString());
                        TablaMagnitud.AddCell((simetria.First().Fecha).ToString());
                        TablaMagnitud.AddCell("Último");
                        TablaMagnitud.AddCell((simetria.Last().Magnitud).ToString());
                        TablaMagnitud.AddCell((simetria.Last().Terapia).ToString());
                        TablaMagnitud.AddCell((simetria.Last().Fecha).ToString());
                        simetria.Sort((x, y) => x.Magnitud.CompareTo(y.Magnitud));
                        TablaMagnitud.AddCell("Máximo");
                        TablaMagnitud.AddCell((simetria.Max(x => x.Magnitud)).ToString());
                        TablaMagnitud.AddCell((simetria.Last().Terapia).ToString());
                        TablaMagnitud.AddCell((simetria.Last().Fecha).ToString());
                        TablaMagnitud.AddCell("Mínimo");
                        TablaMagnitud.AddCell((simetria.Min(x => x.Magnitud)).ToString());
                        TablaMagnitud.AddCell((simetria.First().Terapia).ToString());
                        TablaMagnitud.AddCell((simetria.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaMagnitud);
                        TotalMagnitud = SumaVelocidad / simetria.Count();
                        Chunk MediaChunk = new Chunk(" Media de la simetría de la velocidad: " + TotalMagnitud, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        Paragraph ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);

                        TablaAngulo.AddCell("Valor");
                        TablaAngulo.AddCell("Simetría angular");
                        TablaAngulo.AddCell("Terapia");
                        TablaAngulo.AddCell("Fecha");
                        TablaAngulo.AddCell("Primero");
                        TablaAngulo.AddCell((simetria.First().Angulo).ToString());
                        TablaAngulo.AddCell((simetria.First().Terapia).ToString());
                        TablaAngulo.AddCell((simetria.First().Fecha).ToString());
                        TablaAngulo.AddCell("Último");
                        TablaAngulo.AddCell((simetria.Last().Angulo).ToString());
                        TablaAngulo.AddCell((simetria.Last().Terapia).ToString());
                        TablaAngulo.AddCell((simetria.Last().Fecha).ToString());
                        simetria.Sort((x, y) => x.Angulo.CompareTo(y.Angulo));
                        TablaAngulo.AddCell("Máximo");
                        TablaAngulo.AddCell((simetria.Max(x => x.Angulo)).ToString());
                        TablaAngulo.AddCell((simetria.Last().Terapia).ToString());
                        TablaAngulo.AddCell((simetria.Last().Fecha).ToString());
                        TablaAngulo.AddCell("Mínimo");
                        TablaAngulo.AddCell((simetria.Min(x => x.Angulo)).ToString());
                        TablaAngulo.AddCell((simetria.First().Terapia).ToString());
                        TablaAngulo.AddCell((simetria.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaAngulo);
                        TotalAngulo = SumaAnguloTotal / simetria.Count();
                        MediaChunk = new Chunk(" Media de la simetría del ángulo: " + TotalAngulo, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);
                        iTextSharp.text.Image Imagen = iTextSharp.text.Image.GetInstance(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                        Imagen.Alignment = Element.ALIGN_CENTER;
                        Imagen.ScalePercent((500 / Imagen.Width) * 100);
                        Informe.Add(Imagen);
                        System.IO.File.Delete(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                    }
                }
                else
                {
                    MessageBox.Show("No hay suficientes datos para gráficar la simetría velocidad y ángulo");
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("Error debido a: " + ex.Message
                   + "\r\nError debido a: " + ex.Source
                   + "\r\nError debido a: " + ex.StackTrace
                   + "\r\nError debido a: " + ex.TargetSite);
            }
        }
        /// <summary>
        /// Es la métrica de la evolución de la fuerza, gráfica tanto en la interfaz como en el PDF, el valor es el porcentaje de la evolución de la fuerza teniendo en cuenta la que realiza el paciente y la que realiza el robot
        /// </summary>
        /// <param name="GenerarGrafico">Determina si esta métrica se incluye en el PDF</param>
        /// <param name="Informe">Es el PDF que generamos con las métricas</param>
        /// <param name="ValorTipoTerapia">Indica que tipo de terapía es la seleccionada</param>
        /// <param name="cbPaciente">ComboBox en el que seleccionamos el id del paciente</param>
        /// <param name="CbRangoTerapiaSuperior">ComboBox en el que seleccinamos la ultima terápia a representar</param>
        /// <param name="cbRangoTerapiaInferior">ComboBox en el que seleccinamos la primera terápia a representar</param>
        /// <param name="GrafTrayectoria">Es el Chart donde vamos a graficar la métrica</param>
        /// <param name="bd">Es nuestra base de datos</param>
        /// <param name="Ruta">Ruta de almacenamiento del PDF y temporalmente, de las imagenes que se incluyen en él</param>
        public static void graficaEvolucionFuerza(bool GenerarGrafico, Document Informe, int ValorTipoTerapia, ComboBox cbPaciente, ComboBox CbRangoTerapiaSuperior, ComboBox cbRangoTerapiaInferior, Chart GrafTrayectoria, bbddDataContext bd, string Ruta)
        {
            try
            {
                //Obtenemos los valores que nos interesan de los ComboBox
                string idPacienteSeleccionado = cbPaciente.SelectedValue.ToString();
                string rangoSuperior = CbRangoTerapiaSuperior.SelectedValue.ToString();
                string rangoInferior = cbRangoTerapiaInferior.SelectedValue.ToString();
                int tipoTerapia = ValorTipoTerapia;
                //Realizamos la consulta de los datos que nos interesan
                var resultado = (from Terapia in bd.TerapiaBM
                                 join consulta in bd.Muestra on Terapia.IdTerapia equals consulta.IdTerapia
                                 where Terapia.IdPaciente == int.Parse(idPacienteSeleccionado) && Terapia.IdTerapia > int.Parse(rangoInferior) && Terapia.IdTerapia < int.Parse(rangoSuperior) && Terapia.TipoTerapia == tipoTerapia
                                 orderby consulta.IdTerapia, Terapia.IdTerapia
                                 select new { Terapia.IdTerapia, consulta.IdMuestra, consulta.PosicionX, consulta.PosicionY, consulta.PuntoDeseadoX, consulta.PuntoDeseadoY, consulta.Tiempo, Terapia.IdPaciente, consulta.FuerzaX, consulta.FuerzaY, consulta.FuerzaAsistiva, consulta.VelocidadX, consulta.VelocidadY, Terapia.Fecha }).Distinct().ToList();
                resultado = resultado.OrderBy(o => o.IdTerapia).ToList();
                int contador = resultado.First().IdTerapia;// Contador nos indica en la terapia que nos encontramos
                string datosGrafica;
                string fechaTerapia = "";
                List<Series> evoFuerza = new List<Series>();//Lista en la que almacenamos los datos de interes y los que vamos a gráficar
                List<float> puntoX = new List<float>();
                List<float> puntoY = new List<float>();
                List<float> puntoXf = new List<float>();
                List<float> puntoYf = new List<float>();
                List<float> vx = new List<float>();
                List<float> vy = new List<float>();
                List<float> fuerzaAsistida = new List<float>();//Fuerza realizada por el robot
                List<float> Fy = new List<float>();
                List<float> Fx = new List<float>();
                List<float> listaTiempo = new List<float>();
                string[] tiempoSeparado;
                float Fdx = 0;
                float Fdy = 0;

                float evolucionX = 0;
                float evolucionY = 0;
                float sumaFdx = 0;
                float sumaFdy = 0;
                float sumaFx = 0;
                float sumaFy = 0;
                int m = 1;
                int b = 18;
                float aceleracionX = 0;
                float aceleracionY = 0;
                float diffT = 0;
                //Valores maximos yu minimos para realizar la calibración
                //Para calibrar la posición X 
                float Pxo = (float)resultado.Min(x => x.PosicionX);
                float escaladoX = 1;
                float minPdx = (float)resultado.Min(x => (float)x.PuntoDeseadoX);
                float maxPdx = (float)resultado.Max(x => (float)x.PuntoDeseadoX);
                float pCalibradoX = 0;
                //Para calibrar la posición Y
                float pyo = (float)resultado.Min(x => x.PosicionY);
                float maxPdy = (float)resultado.Max(x => (float)x.PuntoDeseadoY);
                float minPdy = (float)resultado.Min(x => (float)x.PuntoDeseadoY);
                float escaladoY = 1;
                float pCalibradoY = 0;
                int longitud = 0;//Determina la cantidad de datos validos(tratados) en una terapia
                double s1 = 0;
                double s2 = 0;
                double s3 = 0;
                double tiempo = 0;
                int k = 0;
                foreach (var item in resultado)
                {
                    if (k > 4)//Eliminamos los 5 primeros valores por un error de calibración
                    {
                        if (contador == item.IdTerapia)
                        {
                            fechaTerapia = item.Fecha.ToString();
                            tiempoSeparado = (item.Tiempo).Split(':');
                            s1 = double.Parse(tiempoSeparado[0]) * 3600;
                            s2 = double.Parse(tiempoSeparado[1]) * 60;
                            s3 = double.Parse(tiempoSeparado[2]);
                            tiempo = s1 + s2 + s3 / 10000000;
                            listaTiempo.Add((float)tiempo);
                            puntoX.Add(float.Parse((item.PosicionX).ToString()));
                            puntoY.Add(float.Parse((item.PosicionY).ToString()));
                            if (tipoTerapia == 2)
                            {
                                pCalibradoX = Pxo - escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - maxPdx);
                                pCalibradoY = pyo - escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - maxPdy);
                            }
                            else
                            {
                                pCalibradoX = Pxo + escaladoX * (float.Parse(item.PuntoDeseadoX.ToString()) - minPdx);
                                pCalibradoY = pyo + escaladoY * (float.Parse(item.PuntoDeseadoY.ToString()) - minPdy);
                            }
                            puntoYf.Add(pCalibradoX);
                            puntoXf.Add(pCalibradoY);
                            Fx.Add(float.Parse((item.FuerzaX).ToString()));
                            Fy.Add(float.Parse((item.FuerzaY).ToString()));
                            vx.Add(float.Parse((item.VelocidadX).ToString()) / 1000);
                            vy.Add(float.Parse((item.VelocidadY).ToString()) / 1000);
                            fuerzaAsistida.Add(float.Parse((item.FuerzaAsistiva).ToString()));
                            longitud++;

                        }
                        else// Se ha producido un cambio de terapia, luego tratamos los datos de la terapia anterior
                        {

                            if (longitud > 4500) // Cuando en una terapia no tenemos suficientes valores no les tratamos y pasamos a la siguiente.
                            {
                                for (int i = 0; i < longitud - 1; i++)
                                {
                                    diffT = (listaTiempo[i + 1] - listaTiempo[i]);
                                    aceleracionX = (vx[i + 1] - vx[i]) / diffT;
                                    aceleracionY = (vy[i + 1] - vy[i]) / diffT;
                                    //Tratamos los datos que puedan dar infinito o valores númericos no posibles:
                                    if (double.IsNaN(aceleracionX))
                                    {
                                        aceleracionX = 0;
                                    }
                                    if (double.IsNaN(aceleracionY))
                                    {
                                        aceleracionY = 0;
                                    }
                                    if (double.IsInfinity(aceleracionX))
                                    {
                                        aceleracionX = 1;
                                    }
                                    if (double.IsInfinity(aceleracionY))
                                    {
                                        aceleracionY = 1;
                                    }
                                    //Cálculo de la fuerza: Fdx<- m*aceleracionx + b*vx + k*((pxf - px)/1000) y Fdy<- m*aceleraciony + b*vy + k*((pyf - py)/1000)
                                    Fdx = m * aceleracionX + b * vx[i] + fuerzaAsistida[i] * ((puntoXf[i] - puntoX[i]) / 1000);
                                    Fdy = m * aceleracionY + b * vy[i] + fuerzaAsistida[i] * ((puntoYf[i] - puntoY[i]) / 1000);
                                    Fdx = Math.Abs(Fdx);
                                    Fdy = Math.Abs(Fdy);
                                    sumaFdx = sumaFdx + Fdx;
                                    sumaFdy = sumaFdy + Fdy;
                                    sumaFx = sumaFx + Math.Abs(Fx[i]);
                                    sumaFy = sumaFy + Math.Abs(Fy[i]);
                                }
                                // En función de la escala la terapia cambia.
                                if (tipoTerapia > 1)
                                {
                                    evolucionX = 100 * (sumaFx / (longitud * 1000)) / ((sumaFx / (longitud * 1000)) + (sumaFdx / longitud));
                                    evolucionY = 100 * (sumaFy / (longitud * 1000)) / ((sumaFy / (longitud * 1000)) + (sumaFdy / longitud));
                                }
                                else
                                {
                                    evolucionX = 100 * (sumaFx / (longitud)) / ((sumaFx / (longitud)) + (sumaFdx / longitud));
                                    evolucionY = 100 * (sumaFy / (longitud)) / ((sumaFy / (longitud)) + (sumaFdy / longitud));
                                }

                                evoFuerza.Add(
                                new Series
                                {
                                    Fecha = fechaTerapia,
                                    MediaX = evolucionX,
                                    MediaY = evolucionY,
                                    Terapia = contador
                                });
                                puntoXf.Clear();
                                puntoX.Clear();
                                puntoY.Clear();
                                puntoYf.Clear();
                                Fx.Clear();
                                Fy.Clear();
                                fuerzaAsistida.Clear();
                                vx.Clear();
                                vy.Clear();
                                listaTiempo.Clear();
                                contador=item.IdTerapia;
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                                longitud = 0;
                                sumaFdy = 0;
                                sumaFdx = 0;
                                sumaFy = 0;
                                sumaFx = 0;
                            }

                            else
                            {
                                puntoXf.Clear();
                                puntoX.Clear();
                                puntoY.Clear();
                                puntoYf.Clear();
                                Fx.Clear();
                                Fy.Clear();
                                fuerzaAsistida.Clear();
                                vx.Clear();
                                vy.Clear();
                                listaTiempo.Clear();
                                k = 1;//Inicializamos k a 1 porque los 5 primeros valores tienen un error, el primer valor ha sido descartado con el cambio de terapia
                                longitud = 0;
                                contador=item.IdTerapia;
                                sumaFdy = 0;
                                sumaFdx = 0;
                                sumaFy = 0;
                                sumaFx = 0;
                            }
                        }
                    }
                    k++;
                }
                evoFuerza = evoFuerza.OrderBy(o => o.Terapia).ToList();
                if (evoFuerza.Any())
                {
                    //Graficamos
                    GrafTrayectoria.ChartAreas.Clear();
                    GrafTrayectoria.ChartAreas.Add("evoFuerza");
                    GrafTrayectoria.Series.Clear();
                    GrafTrayectoria.DataSource = null;
                    GrafTrayectoria.DataSource = evoFuerza;
                    GrafTrayectoria.Series.Add("Evolución de la fuerza del paciente en el eje x");
                    GrafTrayectoria.Series["Evolución de la fuerza del paciente en el eje x"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Evolución de la fuerza del paciente en el eje x"].YValueMembers = "MediaX";
                    GrafTrayectoria.Series["Evolución de la fuerza del paciente en el eje x"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Evolución de la fuerza del paciente en el eje x"].BorderWidth = 3;
                    GrafTrayectoria.Series.Add("Evolución de la fuerza del paciente en el eje y");
                    GrafTrayectoria.Series["Evolución de la fuerza del paciente en el eje y"].XValueMember = "Terapia";
                    GrafTrayectoria.Series["Evolución de la fuerza del paciente en el eje y"].YValueMembers = "MediaY";
                    GrafTrayectoria.Series["Evolución de la fuerza del paciente en el eje y"].ChartType = System.Windows.Forms.DataVisualization.Charting.SeriesChartType.Line;
                    GrafTrayectoria.Series["Evolución de la fuerza del paciente en el eje y"].BorderWidth = 3;
                    GrafTrayectoria.ChartAreas["evoFuerza"].AxisX.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["evoFuerza"].AxisX.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["evoFuerza"].AxisY.ArrowStyle = System.Windows.Forms.DataVisualization.Charting.AxisArrowStyle.Triangle;//AxisArrowStyle.Triangle;
                    GrafTrayectoria.ChartAreas["evoFuerza"].AxisY.LineColor = Color.Black;
                    GrafTrayectoria.ChartAreas["evoFuerza"].CursorX.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["evoFuerza"].CursorY.LineWidth = 9;
                    GrafTrayectoria.ChartAreas["evoFuerza"].Visible = true;
                    GrafTrayectoria.ChartAreas["evoFuerza"].AxisX.Title = "Terapias";
                    GrafTrayectoria.ChartAreas["evoFuerza"].AxisY.Title = "Porcentaje de fuerza (%)";
                    GrafTrayectoria.ChartAreas["evoFuerza"].AxisX.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.ChartAreas["evoFuerza"].AxisY.TitleForeColor = Color.Fuchsia;
                    GrafTrayectoria.Titles.Clear();
                    GrafTrayectoria.Titles.Add("Evolución de fuerza");
                    datosGrafica = "Paciente = " + idPacienteSeleccionado + " Tipo de terapia = " + tipoTerapia + " Rango = Desde " + evoFuerza.First().Terapia + " hasta " + contador;
                    GrafTrayectoria.Titles.Add(datosGrafica);
                    if (GenerarGrafico)
                    {
                        //Generamos el informe con una breve descripción, tablas de información y la gráfica
                        float SumaFxTotal = 0;
                        float SumaFyTotal = 0;
                        float TotalMediaFx = 0;
                        float TotalMediaFy = 0;
                        string NombreImagen = "Evolucion_Fuerza_Paciente_";
                        GrafTrayectoria.SaveImage(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png", System.Drawing.Imaging.ImageFormat.Png);
                        Chunk ChunkDescripcion = new Chunk("Esta medida va a marcar la evolución de la fuerza que tenga el paciente. Para ello lo que valoramos es no solo la fuerza que aplica el paciente, sino también la fuerza con la que le ayuda el robot. Para calcular la evolución vamos a tomar la fuerza que aplica el paciente y la vamos a dividir entre la suma de la fuerza que aplica el robot y la fuerza que aplica el paciente. \nEl índice será un porcentaje de la fuerza en x y en y que realiza el paciente con respecto a la fuerza que hace el paciente y la fuerza asistida que recibe.", FontFactory.GetFont("ARIAL", 11));
                        Paragraph descripcion = new Paragraph(ChunkDescripcion);
                        descripcion.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(descripcion);
                        PdfPTable TablaFx = new PdfPTable(4);
                        PdfPTable TablaFy = new PdfPTable(4);
                        foreach (Series item in evoFuerza)
                        {
                            SumaFxTotal = SumaFxTotal + item.MediaX;
                            SumaFyTotal = SumaFyTotal + item.MediaY;

                        }
                        TablaFx.AddCell("Valor");
                        TablaFx.AddCell("Evolución en X");
                        TablaFx.AddCell("Terapia");
                        TablaFx.AddCell("Fecha");
                        TablaFx.AddCell("Primero");
                        TablaFx.AddCell((evoFuerza.First().MediaX).ToString());
                        TablaFx.AddCell((evoFuerza.First().Terapia).ToString());
                        TablaFx.AddCell((evoFuerza.First().Fecha).ToString());
                        TablaFx.AddCell("Último");
                        TablaFx.AddCell((evoFuerza.Last().MediaX).ToString());
                        TablaFx.AddCell((evoFuerza.Last().Terapia).ToString());
                        TablaFx.AddCell((evoFuerza.Last().Fecha).ToString());
                        evoFuerza.Sort((x, y) => x.MediaX.CompareTo(y.MediaX));
                        TablaFx.AddCell("Máximo");
                        TablaFx.AddCell((evoFuerza.Max(x => x.MediaX)).ToString());
                        TablaFx.AddCell((evoFuerza.Last().Terapia).ToString());
                        TablaFx.AddCell((evoFuerza.Last().Fecha).ToString());
                        TablaFx.AddCell("Mínimo");
                        TablaFx.AddCell((evoFuerza.Min(x => x.MediaX)).ToString());
                        TablaFx.AddCell((evoFuerza.First().Terapia).ToString());
                        TablaFx.AddCell((evoFuerza.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaFx);
                        TotalMediaFx = SumaFxTotal / evoFuerza.Count();
                        Chunk MediaChunk = new Chunk(" Media de evolución en X: " + TotalMediaFx, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        Paragraph ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);

                        TablaFy.AddCell("Valor");
                        TablaFy.AddCell("Evolución en Y");
                        TablaFy.AddCell("Terapia");
                        TablaFy.AddCell("Fecha");
                        TablaFy.AddCell("Primero");
                        TablaFy.AddCell((evoFuerza.First().MediaY).ToString());
                        TablaFy.AddCell((evoFuerza.First().Terapia).ToString());
                        TablaFy.AddCell((evoFuerza.First().Fecha).ToString());
                        TablaFy.AddCell("Último");
                        TablaFy.AddCell((evoFuerza.Last().MediaY).ToString());
                        TablaFy.AddCell((evoFuerza.Last().Terapia).ToString());
                        TablaFy.AddCell((evoFuerza.Last().Fecha).ToString());
                        evoFuerza.Sort((x, y) => x.MediaY.CompareTo(y.MediaY)); ;
                        TablaFy.AddCell("Máximo");
                        TablaFy.AddCell((evoFuerza.Max(x => x.MediaY)).ToString());
                        TablaFy.AddCell((evoFuerza.Last().Terapia).ToString());
                        TablaFy.AddCell((evoFuerza.Last().Fecha).ToString());
                        TablaFy.AddCell("Mínimo");
                        TablaFy.AddCell((evoFuerza.Min(x => x.MediaY)).ToString());
                        TablaFy.AddCell((evoFuerza.First().Terapia).ToString());
                        TablaFy.AddCell((evoFuerza.First().Fecha).ToString());
                        Informe.Add(new Paragraph(" "));
                        Informe.Add(TablaFy);
                        TotalMediaFy = SumaFyTotal / evoFuerza.Count();
                        MediaChunk = new Chunk(" Media de evolución en Y: " + TotalMediaFy, FontFactory.GetFont("ARIAL", 12, iTextSharp.text.Font.UNDERLINE, BaseColor.BLUE));
                        ParrafoMeida = new Paragraph(MediaChunk);
                        ParrafoMeida.Alignment = Element.ALIGN_CENTER;
                        Informe.Add(ParrafoMeida);
                        iTextSharp.text.Image Imagen = iTextSharp.text.Image.GetInstance(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                        Imagen.Alignment = Element.ALIGN_CENTER;
                        Imagen.ScalePercent((500 / Imagen.Width) * 100);
                        Informe.Add(Imagen);
                        //System.IO.File.Delete(Ruta + NombreImagen + cbPaciente.SelectedValue + ".Png");
                    }
                }
                else
                {
                    MessageBox.Show("No hay suficientes datos para gráficar la evolución de la fuerza");
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show("Error debido a: " + ex.Message
                   + "\r\nError debido a: " + ex.Source
                   + "\r\nError debido a: " + ex.StackTrace
                   + "\r\nError debido a: " + ex.TargetSite);
            }
        }
        /// <summary>
        /// Función que comprueba que que los ComboBox de Paciente, Terapia y Tipo Terapia han sido correctamente seleccionados
        /// </summary>
        /// <param name="cbPaciente">ComboBox en el que seleccionamos el id del paciente</param>
        /// <param name="cbTipoTerapia">ComboBox en el que seleccionamos el tipo de terapia</param>
        /// <returns>Devuelve true si se ha hecho una correcta selección y false en caso contrario</returns>
        public static  bool comprobarSeleccion(ComboBox cbPaciente, ComboBox cbTipoTerapia)
        {          
            if (cbPaciente.SelectedIndex < 0)
            {
                MessageBox.Show("Porfavor, elija un paciente.");
                return false;
            }
            else if (cbTipoTerapia.SelectedIndex < 0)
            {
                MessageBox.Show("Porfavor, elija una terapia.");
                return false;
            }
            else
            {
                return true;
            }
        }
        /// <summary>
        /// Función que se encarga de realizar el cabecero del pdf de cada una de las métricas representadas.
        /// </summary>
        /// <param name="Informe">Es el PDF que generamos con las métricas</param>
        /// <param name="Metrica">Cadena de carateres que nos indica el titulo del apartado de la métrica correspondiente</param>
        /// <param name="cbPaciente">ComboBox en el que seleccionamos el id del paciente</param>
        /// <param name="ValorTipoTerapia">Indica que tipo de terapía es la seleccionada</param>
        public static void generaCabecero(Document Informe, string Metrica, ComboBox cbPaciente,int ValorTipoTerapia)
        {
            //Función que se encarga de realizar el cabecero del pdf de cada una de las métricas representadas.
            Chunk Cabecero = new Chunk(" Paciente " + cbPaciente.SelectedValue + "/" + Metrica + " / Terapia tipo " + ValorTipoTerapia, FontFactory.GetFont("ARIAL", 19, iTextSharp.text.Font.BOLD, BaseColor.RED));
            Paragraph titulo1 = new Paragraph(Cabecero);
            titulo1.Alignment = Element.ALIGN_CENTER;
            Paragraph separador = new Paragraph("------------------------------------------------------------------------------------------------------------");
            separador.Alignment = Element.ALIGN_CENTER;
            Informe.Add(separador);
            Informe.Add(titulo1);
            Informe.Add(separador);
        }
    }
}